Crate stripe_payment

Crate stripe_payment 

This crate provides Rust bindings to the Stripe HTTP API, specifically for requests mentioned in the Payment Methods and Payment Links sections of the Stripe API docs

Modules

bank_account
card
confirmation_token
payment_attempt_record
payment_link
payment_method
payment_method_configuration
payment_method_domain
source

Structs

AlmaInstallments
AmazonPayUnderlyingPaymentMethodFundingDetails
BankAccount
These bank accounts are payment methods on Customer objects.
BankAccountId
Card
You can store multiple cards on a customer in order to charge the customer later. You can also store multiple debit cards on a recipient in order to transfer to those cards later.
CardGeneratedFromPaymentMethodDetails
CardId
CardIssuingAccountTermsOfService
CardMandatePaymentMethodDetails
ConfirmationToken
ConfirmationTokens help transport client side data collected by Stripe JS over to your server for confirming a PaymentIntent or SetupIntent. If the confirmation is successful, values present on the ConfirmationToken are written onto the Intent.
ConfirmationTokenId
ConfirmationTokensResourceMandateData
Data used for generating a Mandate.
ConfirmationTokensResourceMandateDataBuilder
ConfirmationTokensResourceMandateDataResourceCustomerAcceptance
This hash contains details about the customer acceptance of the Mandate.
ConfirmationTokensResourceMandateDataResourceCustomerAcceptanceBuilder
ConfirmationTokensResourceMandateDataResourceCustomerAcceptanceResourceOnline
This hash contains details about the online acceptance.
ConfirmationTokensResourceMandateDataResourceCustomerAcceptanceResourceOnlineBuilder
ConfirmationTokensResourcePaymentMethodOptions
Payment-method-specific configuration
ConfirmationTokensResourcePaymentMethodOptionsBuilder
ConfirmationTokensResourcePaymentMethodOptionsResourceCard
This hash contains the card payment method options.
ConfirmationTokensResourcePaymentMethodOptionsResourceCardBuilder
ConfirmationTokensResourcePaymentMethodOptionsResourceCardResourceInstallment
Installment configuration for payments.
ConfirmationTokensResourcePaymentMethodOptionsResourceCardResourceInstallmentBuilder
ConfirmationTokensResourcePaymentMethodPreview
Details of the PaymentMethod collected by Payment Element
ConfirmationTokensResourcePaymentMethodPreviewBuilder
ConfirmationTokensResourceShipping
ConfirmationTokensResourceShippingBuilder
CustomLogo
DeletedBankAccount
DeletedCard
DeletedExternalAccountBuilder
DeletedPaymentSourceBuilder
ExternalAccountRequirements
InternalCard
KlarnaAddress
KlarnaPayerDetails
Networks
PaymentAttemptRecord
A Payment Attempt Record represents an individual attempt at making a payment, on or off Stripe. Each payment attempt tries to collect a fixed amount of money from a fixed customer and payment method. Payment Attempt Records are attached to Payment Records. Only one attempt per Payment Record. can have guaranteed funds.
PaymentAttemptRecordId
PaymentFlowsPrivatePaymentMethodsAlipay
PaymentFlowsPrivatePaymentMethodsAlipayDetails
PaymentFlowsPrivatePaymentMethodsCardDetailsApiResourceEnterpriseFeaturesExtendedAuthorizationExtendedAuthorization
PaymentFlowsPrivatePaymentMethodsCardDetailsApiResourceEnterpriseFeaturesIncrementalAuthorizationIncrementalAuthorization
PaymentFlowsPrivatePaymentMethodsCardDetailsApiResourceEnterpriseFeaturesOvercaptureOvercapture
PaymentFlowsPrivatePaymentMethodsCardDetailsApiResourceMulticapture
PaymentFlowsPrivatePaymentMethodsCardPresentCommonWallet
PaymentFlowsPrivatePaymentMethodsKlarnaDob
PaymentLink
A payment link is a shareable URL that will take your customers to a hosted payment page. A payment link can be shared and used multiple times.
PaymentLinkId
PaymentLinksResourceAfterCompletion
PaymentLinksResourceAutomaticTax
PaymentLinksResourceBusinessName
PaymentLinksResourceCompletedSessions
PaymentLinksResourceCompletionBehaviorConfirmationPage
PaymentLinksResourceCompletionBehaviorRedirect
PaymentLinksResourceConsentCollection
PaymentLinksResourceCustomFields
PaymentLinksResourceCustomFieldsDropdown
PaymentLinksResourceCustomFieldsDropdownOption
PaymentLinksResourceCustomFieldsLabel
PaymentLinksResourceCustomFieldsNumeric
PaymentLinksResourceCustomFieldsText
PaymentLinksResourceCustomText
PaymentLinksResourceCustomTextPosition
PaymentLinksResourceIndividualName
PaymentLinksResourceInvoiceCreation
PaymentLinksResourceInvoiceSettings
PaymentLinksResourceNameCollection
PaymentLinksResourceOptionalItem
PaymentLinksResourceOptionalItemAdjustableQuantity
PaymentLinksResourcePaymentIntentData
PaymentLinksResourcePaymentMethodReuseAgreement
PaymentLinksResourcePhoneNumberCollection
PaymentLinksResourceRestrictions
PaymentLinksResourceShippingAddressCollection
PaymentLinksResourceShippingOption
PaymentLinksResourceSubscriptionData
PaymentLinksResourceSubscriptionDataInvoiceSettings
PaymentLinksResourceTaxIdCollection
PaymentLinksResourceTransferData
PaymentMethod
PaymentMethod objects represent your customer’s payment instruments. You can use them with PaymentIntents to collect payments or save them to. Customer objects to store instrument details for future payments.
PaymentMethodAcssDebit
PaymentMethodAffirm
PaymentMethodAfterpayClearpay
PaymentMethodAlma
PaymentMethodAmazonPay
PaymentMethodAuBecsDebit
PaymentMethodBacsDebit
PaymentMethodBancontact
PaymentMethodBillie
PaymentMethodBlik
PaymentMethodBoleto
PaymentMethodCard
PaymentMethodCardChecks
PaymentMethodCardGeneratedCard
PaymentMethodCardPresent
PaymentMethodCardPresentNetworks
PaymentMethodCardWallet
PaymentMethodCardWalletAmexExpressCheckout
PaymentMethodCardWalletApplePay
PaymentMethodCardWalletGooglePay
PaymentMethodCardWalletLink
PaymentMethodCardWalletMasterpass
PaymentMethodCardWalletSamsungPay
PaymentMethodCardWalletVisaCheckout
PaymentMethodCashapp
PaymentMethodConfigBizPaymentMethodConfigurationDetails
PaymentMethodConfigResourceDisplayPreference
PaymentMethodConfigResourceDisplayPreferenceBuilder
PaymentMethodConfigResourcePaymentMethodProperties
PaymentMethodConfigResourcePaymentMethodPropertiesBuilder
PaymentMethodConfiguration
PaymentMethodConfigurations control which payment methods are displayed to your customers when you don’t explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.
PaymentMethodConfigurationId
PaymentMethodCrypto
PaymentMethodCustom
PaymentMethodCustomerBalance
PaymentMethodDetails
PaymentMethodDetailsAchCreditTransfer
PaymentMethodDetailsAchDebit
PaymentMethodDetailsAcssDebit
PaymentMethodDetailsAffirm
PaymentMethodDetailsAfterpayClearpay
PaymentMethodDetailsAlma
PaymentMethodDetailsAmazonPay
PaymentMethodDetailsAuBecsDebit
PaymentMethodDetailsBacsDebit
PaymentMethodDetailsBancontact
PaymentMethodDetailsBillie
PaymentMethodDetailsBlik
PaymentMethodDetailsBoleto
PaymentMethodDetailsCard
PaymentMethodDetailsCardChecks
PaymentMethodDetailsCardInstallments
PaymentMethodDetailsCardInstallmentsPlan
PaymentMethodDetailsCardNetworkToken
PaymentMethodDetailsCardPresent
PaymentMethodDetailsCardPresentOffline
PaymentMethodDetailsCardPresentReceipt
PaymentMethodDetailsCardWallet
PaymentMethodDetailsCardWalletAmexExpressCheckout
PaymentMethodDetailsCardWalletApplePay
PaymentMethodDetailsCardWalletGooglePay
PaymentMethodDetailsCardWalletLink
PaymentMethodDetailsCardWalletMasterpass
PaymentMethodDetailsCardWalletSamsungPay
PaymentMethodDetailsCardWalletVisaCheckout
PaymentMethodDetailsCashapp
PaymentMethodDetailsCrypto
PaymentMethodDetailsCustomerBalance
PaymentMethodDetailsEps
PaymentMethodDetailsFpx
PaymentMethodDetailsGiropay
PaymentMethodDetailsGrabpay
PaymentMethodDetailsIdeal
PaymentMethodDetailsInteracPresent
PaymentMethodDetailsInteracPresentReceipt
PaymentMethodDetailsKakaoPay
PaymentMethodDetailsKlarna
PaymentMethodDetailsKonbini
PaymentMethodDetailsKonbiniStore
PaymentMethodDetailsKrCard
PaymentMethodDetailsLink
PaymentMethodDetailsMbWay
PaymentMethodDetailsMobilepay
PaymentMethodDetailsMultibanco
PaymentMethodDetailsNaverPay
PaymentMethodDetailsNzBankAccount
PaymentMethodDetailsOxxo
PaymentMethodDetailsP24
PaymentMethodDetailsPassthroughCard
PaymentMethodDetailsPayByBank
PaymentMethodDetailsPayco
PaymentMethodDetailsPaymentRecordAcssDebit
PaymentMethodDetailsPaymentRecordAffirm
PaymentMethodDetailsPaymentRecordAfterpayClearpay
PaymentMethodDetailsPaymentRecordAlma
PaymentMethodDetailsPaymentRecordAmazonPay
PaymentMethodDetailsPaymentRecordBancontact
PaymentMethodDetailsPaymentRecordBillie
PaymentMethodDetailsPaymentRecordBlik
PaymentMethodDetailsPaymentRecordBoleto
PaymentMethodDetailsPaymentRecordCashapp
PaymentMethodDetailsPaymentRecordEps
PaymentMethodDetailsPaymentRecordGiropay
PaymentMethodDetailsPaymentRecordIdeal
PaymentMethodDetailsPaymentRecordKakaoPay
PaymentMethodDetailsPaymentRecordKonbini
PaymentMethodDetailsPaymentRecordMbWay
PaymentMethodDetailsPaymentRecordMobilepay
PaymentMethodDetailsPaymentRecordMultibanco
PaymentMethodDetailsPaymentRecordNaverPay
PaymentMethodDetailsPaymentRecordOxxo
PaymentMethodDetailsPaymentRecordPayByBank
PaymentMethodDetailsPaymentRecordPayco
PaymentMethodDetailsPaymentRecordPaynow
PaymentMethodDetailsPaymentRecordPix
PaymentMethodDetailsPaymentRecordPromptpay
PaymentMethodDetailsPaymentRecordSamsungPay
PaymentMethodDetailsPaymentRecordSepaDebit
PaymentMethodDetailsPaymentRecordSofort
PaymentMethodDetailsPaymentRecordSwish
PaymentMethodDetailsPaymentRecordTwint
PaymentMethodDetailsPaymentRecordUpi
PaymentMethodDetailsPaymentRecordUsBankAccount
PaymentMethodDetailsPaymentRecordWechatPay
PaymentMethodDetailsPaymentRecordZip
PaymentMethodDetailsPaynow
PaymentMethodDetailsPaypal
PaymentMethodDetailsPayto
PaymentMethodDetailsPix
PaymentMethodDetailsPromptpay
PaymentMethodDetailsRevolutPay
PaymentMethodDetailsSamsungPay
PaymentMethodDetailsSatispay
PaymentMethodDetailsSepaCreditTransfer
PaymentMethodDetailsSepaDebit
PaymentMethodDetailsSofort
PaymentMethodDetailsStripeAccount
PaymentMethodDetailsSunbit
PaymentMethodDetailsSwish
PaymentMethodDetailsTwint
PaymentMethodDetailsUpi
PaymentMethodDetailsUsBankAccount
PaymentMethodDetailsWechat
PaymentMethodDetailsWechatPay
PaymentMethodDetailsZip
PaymentMethodDomain
A payment method domain represents a web domain that you have registered with Stripe. Stripe Elements use registered payment method domains to control where certain payment methods are shown.
PaymentMethodDomainId
PaymentMethodDomainResourcePaymentMethodStatus
Indicates the status of a specific payment method on a payment method domain.
PaymentMethodDomainResourcePaymentMethodStatusBuilder
PaymentMethodDomainResourcePaymentMethodStatusDetails
Contains additional details about the status of a payment method for a specific payment method domain.
PaymentMethodDomainResourcePaymentMethodStatusDetailsBuilder
PaymentMethodEps
PaymentMethodFpx
PaymentMethodGiropay
PaymentMethodGrabpay
PaymentMethodId
PaymentMethodIdeal
PaymentMethodInteracPresent
PaymentMethodKakaoPay
PaymentMethodKlarna
PaymentMethodKonbini
PaymentMethodKrCard
PaymentMethodLink
PaymentMethodMbWay
PaymentMethodMobilepay
PaymentMethodMultibanco
PaymentMethodNaverPay
PaymentMethodNzBankAccount
PaymentMethodOptionsAffirm
PaymentMethodOptionsAfterpayClearpay
PaymentMethodOptionsAlipay
PaymentMethodOptionsAlma
PaymentMethodOptionsAmazonPay
PaymentMethodOptionsBancontact
PaymentMethodOptionsBillie
PaymentMethodOptionsBoleto
PaymentMethodOptionsCardInstallments
PaymentMethodOptionsCardMandateOptions
PaymentMethodOptionsCardPresent
PaymentMethodOptionsCardPresentRouting
PaymentMethodOptionsCashapp
PaymentMethodOptionsCrypto
PaymentMethodOptionsCustomerBalance
PaymentMethodOptionsCustomerBalanceBankTransfer
PaymentMethodOptionsCustomerBalanceEuBankAccount
PaymentMethodOptionsFpx
PaymentMethodOptionsGiropay
PaymentMethodOptionsGrabpay
PaymentMethodOptionsIdeal
PaymentMethodOptionsInteracPresent
PaymentMethodOptionsKlarna
PaymentMethodOptionsKonbini
PaymentMethodOptionsKrCard
PaymentMethodOptionsMandateOptionsPix
PaymentMethodOptionsMandateOptionsUpi
PaymentMethodOptionsMbWay
PaymentMethodOptionsMultibanco
PaymentMethodOptionsOxxo
PaymentMethodOptionsP24
PaymentMethodOptionsPayByBank
PaymentMethodOptionsPaynow
PaymentMethodOptionsPaypal
PaymentMethodOptionsPix
PaymentMethodOptionsPromptpay
PaymentMethodOptionsRevolutPay
PaymentMethodOptionsSatispay
PaymentMethodOptionsSofort
PaymentMethodOptionsTwint
PaymentMethodOptionsUpi
PaymentMethodOptionsUsBankAccountMandateOptions
PaymentMethodOptionsWechatPay
PaymentMethodOptionsZip
PaymentMethodOxxo
PaymentMethodP24
PaymentMethodPayByBank
PaymentMethodPayco
PaymentMethodPaynow
PaymentMethodPaypal
PaymentMethodPayto
PaymentMethodPix
PaymentMethodPromptpay
PaymentMethodRevolutPay
PaymentMethodSamsungPay
PaymentMethodSatispay
PaymentMethodSepaDebit
PaymentMethodSofort
PaymentMethodSunbit
PaymentMethodSwish
PaymentMethodTwint
PaymentMethodUpi
PaymentMethodUsBankAccount
PaymentMethodUsBankAccountBlocked
PaymentMethodUsBankAccountStatusDetails
PaymentMethodWechatPay
PaymentMethodZip
PaymentsPrimitivesPaymentRecordsResourceAddress
A representation of a physical address.
PaymentsPrimitivesPaymentRecordsResourceAmount
A representation of an amount of money, consisting of an amount and a currency.
PaymentsPrimitivesPaymentRecordsResourceBillingDetails
Billing details used by the customer for this payment.
PaymentsPrimitivesPaymentRecordsResourceCustomerDetails
Information about the customer for this payment.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodAlmaDetailsResourceInstallments
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodAmazonPayDetailsResourceFunding
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodAmazonPayDetailsResourceFundingResourceFundingCard
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetails
Details of the card used for this payment attempt.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceChecks
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceInstallmentPlan
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceInstallments
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceNetworkToken
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceThreeDSecure
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceWallet
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceWalletResourceApplePay
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceWalletResourceGooglePay
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCustomDetails
Custom Payment Methods represent Payment Method types not modeled directly in the Stripe API. This resource consists of details about the custom payment method used for this payment attempt.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodDetails
Details about the Payment Method used in this payment attempt.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodKonbiniDetailsResourceStore
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodMobilepayDetailsResourceCard
PaymentsPrimitivesPaymentRecordsResourceProcessorDetails
Processor information associated with this payment.
PaymentsPrimitivesPaymentRecordsResourceProcessorDetailsResourceCustomDetails
Custom processors represent payment processors not modeled directly in the Stripe API. This resource consists of details about the custom processor used for this payment attempt.
PaymentsPrimitivesPaymentRecordsResourceShippingDetails
The customer’s shipping information associated with this payment.
PaypalSellerProtection
RevolutPayUnderlyingPaymentMethodFundingDetails
SepaDebitGeneratedFrom
Source objects allow you to accept a variety of payment methods. They represent a customer’s payment instrument, and can be used with the Stripe API just like a Card object: once chargeable, they can be charged, or can be attached to customers.
SourceCodeVerificationFlow
SourceId
SourceMandateNotification
Source mandate notifications should be created when a notification related to a source mandate must be sent to the payer. They will trigger a webhook or deliver an email to the customer.
SourceMandateNotificationAcssDebitData
SourceMandateNotificationAcssDebitDataBuilder
SourceMandateNotificationBacsDebitData
SourceMandateNotificationBacsDebitDataBuilder
SourceMandateNotificationBuilder
SourceMandateNotificationId
SourceMandateNotificationSepaDebitData
SourceMandateNotificationSepaDebitDataBuilder
SourceOrder
SourceOrderItem
SourceOwner
SourceReceiverFlow
SourceRedirectFlow
SourceTransaction
Some payment methods have no required amount that a customer must send. Customers can be instructed to send any amount, and it can be made up of multiple transactions. As such, sources can have multiple associated transactions.
SourceTransactionAchCreditTransferData
SourceTransactionChfCreditTransferData
SourceTransactionGbpCreditTransferData
SourceTransactionId
SourceTransactionPaperCheckData
SourceTransactionSepaCreditTransferData
SourceTypeAchCreditTransfer
SourceTypeAchDebit
SourceTypeAcssDebit
SourceTypeAlipay
SourceTypeAuBecsDebit
SourceTypeBancontact
SourceTypeCard
SourceTypeCardPresent
SourceTypeEps
SourceTypeGiropay
SourceTypeIdeal
SourceTypeKlarna
SourceTypeMultibanco
SourceTypeP24
SourceTypeSepaCreditTransfer
SourceTypeSepaDebit
SourceTypeSofort
SourceTypeThreeDSecure
SourceTypeWechat
ThreeDSecureDetailsCharge
ThreeDSecureUsage
UsBankAccountNetworks

Enums

AmazonPayUnderlyingPaymentMethodFundingDetailsType
funding type of the underlying payment method.
BankAccountAvailablePayoutMethods
A set of available payout methods for this bank account. Only values from this set should be passed as the method when creating a payout.
CardAllowRedisplay
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.
CardAvailablePayoutMethods
A set of available payout methods for this card. Only values from this set should be passed as the method when creating a payout.
CardRegulatedStatus
Status of a card based on the card issuer.
ConfirmationTokenSetupFutureUsage
ConfirmationTokensResourcePaymentMethodPreviewAllowRedisplay
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.
ConfirmationTokensResourcePaymentMethodPreviewType
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
DeletedExternalAccount
The resource representing a Stripe Polymorphic
DeletedPaymentSource
The resource representing a Stripe Polymorphic
PaymentAttemptRecordCustomerPresence
Indicates whether the customer was present in your checkout flow during this payment.
PaymentAttemptRecordReportedBy
Indicates who reported the payment.
PaymentFlowsPrivatePaymentMethodsCardDetailsApiResourceEnterpriseFeaturesExtendedAuthorizationExtendedAuthorizationStatus
Indicates whether or not the capture window is extended beyond the standard authorization.
PaymentFlowsPrivatePaymentMethodsCardDetailsApiResourceEnterpriseFeaturesIncrementalAuthorizationIncrementalAuthorizationStatus
Indicates whether or not the incremental authorization feature is supported.
PaymentFlowsPrivatePaymentMethodsCardDetailsApiResourceEnterpriseFeaturesOvercaptureOvercaptureStatus
Indicates whether or not the authorized amount can be over-captured.
PaymentFlowsPrivatePaymentMethodsCardDetailsApiResourceMulticaptureStatus
Indicates whether or not multiple captures are supported.
PaymentFlowsPrivatePaymentMethodsCardPresentCommonWalletType
The type of mobile wallet, one of apple_pay, google_pay, samsung_pay, or unknown.
PaymentLinkBillingAddressCollection
PaymentLinkCustomerCreation
Configuration for Customer creation during checkout.
PaymentLinkPaymentMethodCollection
Configuration for collecting a payment method during checkout. Defaults to always.
PaymentLinkPaymentMethodTypes
PaymentLinkSubmitType
PaymentLinksResourceAfterCompletionType
The specified behavior after the purchase is complete.
PaymentLinksResourceConsentCollectionPromotions
If set to auto, enables the collection of customer consent for promotional communications.
PaymentLinksResourceConsentCollectionTermsOfService
If set to required, it requires cutomers to accept the terms of service before being able to pay. If set to none, customers won’t be shown a checkbox to accept the terms of service.
PaymentLinksResourceCustomFieldsLabelType
The type of the label.
PaymentLinksResourceCustomFieldsType
The type of the field.
PaymentLinksResourcePaymentIntentDataCaptureMethod
Indicates when the funds will be captured from the customer’s account.
PaymentLinksResourcePaymentIntentDataSetupFutureUsage
Indicates that you intend to make future payments with the payment method collected during checkout.
PaymentLinksResourcePaymentMethodReuseAgreementPosition
Determines the position and visibility of the payment method reuse agreement in the UI. When set to auto, Stripe’s defaults will be used.
PaymentLinksResourceShippingAddressCollectionAllowedCountries
An array of two-letter ISO country codes representing which countries Checkout should provide as options for shipping locations. Unsupported country codes: AS, CX, CC, CU, HM, IR, KP, MH, FM, NF, MP, PW, SD, SY, UM, VI.
PaymentLinksResourceTaxIdCollectionRequired
PaymentMethodAllowRedisplay
PaymentMethodCardPresentReadMethod
How card details were read in this transaction.
PaymentMethodCardRegulatedStatus
Status of a card based on the card issuer.
PaymentMethodCardWalletType
The type of the card wallet, one of amex_express_checkout, apple_pay, google_pay, masterpass, samsung_pay, visa_checkout, or link. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.
PaymentMethodConfigResourceDisplayPreferencePreference
The account’s display preference.
PaymentMethodConfigResourceDisplayPreferenceValue
The effective display preference value.
PaymentMethodDetailsAchDebitAccountHolderType
Type of entity that holds the account. This can be either individual or company.
PaymentMethodDetailsBancontactPreferredLanguage
Preferred language of the Bancontact authorization page that the customer is redirected to. Can be one of en, de, fr, or nl
PaymentMethodDetailsCardInstallmentsPlanInterval
For fixed_count installment plans, this is the interval between installment payments your customer will make to their credit card. One of month.
PaymentMethodDetailsCardInstallmentsPlanType
Type of installment plan, one of fixed_count, bonus, or revolving.
PaymentMethodDetailsCardPresentOfflineType
The method used to process this payment method offline. Only deferred is allowed.
PaymentMethodDetailsCardPresentReadMethod
How card details were read in this transaction.
PaymentMethodDetailsCardPresentReceiptAccountType
The type of account being debited or credited
PaymentMethodDetailsCardRegulatedStatus
Status of a card based on the card issuer.
PaymentMethodDetailsCardWalletType
The type of the card wallet, one of amex_express_checkout, apple_pay, google_pay, masterpass, samsung_pay, visa_checkout, or link. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.
PaymentMethodDetailsCryptoNetwork
The blockchain network that the transaction was sent on.
PaymentMethodDetailsCryptoTokenCurrency
The token currency that the transaction was sent with.
PaymentMethodDetailsEpsBank
The customer’s bank. Should be one of arzte_und_apotheker_bank, austrian_anadi_bank_ag, bank_austria, bankhaus_carl_spangler, bankhaus_schelhammer_und_schattera_ag, bawag_psk_ag, bks_bank_ag, brull_kallmus_bank_ag, btv_vier_lander_bank, capital_bank_grawe_gruppe_ag, deutsche_bank_ag, dolomitenbank, easybank_ag, erste_bank_und_sparkassen, hypo_alpeadriabank_international_ag, hypo_noe_lb_fur_niederosterreich_u_wien, hypo_oberosterreich_salzburg_steiermark, hypo_tirol_bank_ag, hypo_vorarlberg_bank_ag, hypo_bank_burgenland_aktiengesellschaft, marchfelder_bank, oberbank_ag, raiffeisen_bankengruppe_osterreich, schoellerbank_ag, sparda_bank_wien, volksbank_gruppe, volkskreditbank_ag, or vr_bank_braunau.
PaymentMethodDetailsFpxAccountHolderType
Account holder type, if provided. Can be one of individual or company.
PaymentMethodDetailsFpxBank
The customer’s bank. Can be one of affin_bank, agrobank, alliance_bank, ambank, bank_islam, bank_muamalat, bank_rakyat, bsn, cimb, hong_leong_bank, hsbc, kfh, maybank2u, ocbc, public_bank, rhb, standard_chartered, uob, deutsche_bank, maybank2e, pb_enterprise, or bank_of_china.
PaymentMethodDetailsIdealBank
The customer’s bank. Can be one of abn_amro, adyen, asn_bank, bunq, buut, finom, handelsbanken, ing, knab, mollie, moneyou, n26, nn, rabobank, regiobank, revolut, sns_bank, triodos_bank, van_lanschot, or yoursafe.
PaymentMethodDetailsIdealBic
The Bank Identifier Code of the customer’s bank.
PaymentMethodDetailsInteracPresentReadMethod
How card details were read in this transaction.
PaymentMethodDetailsInteracPresentReceiptAccountType
The type of account being debited or credited
PaymentMethodDetailsKonbiniStoreChain
The name of the convenience store chain where the payment was completed.
PaymentMethodDetailsKrCardBrand
The local credit or debit card brand.
PaymentMethodDetailsP24Bank
The customer’s bank. Can be one of ing, citi_handlowy, tmobile_usbugi_bankowe, plus_bank, etransfer_pocztowy24, banki_spbdzielcze, bank_nowy_bfg_sa, getin_bank, velobank, blik, noble_pay, ideabank, envelobank, santander_przelew24, nest_przelew, mbank_mtransfer, inteligo, pbac_z_ipko, bnp_paribas, credit_agricole, toyota_bank, bank_pekao_sa, volkswagen_bank, bank_millennium, alior_bank, or boz.
PaymentMethodDetailsPaymentRecordBancontactPreferredLanguage
Preferred language of the Bancontact authorization page that the customer is redirected to. Can be one of en, de, fr, or nl.
PaymentMethodDetailsPaymentRecordEpsBank
The customer’s bank. Should be one of arzte_und_apotheker_bank, austrian_anadi_bank_ag, bank_austria, bankhaus_carl_spangler, bankhaus_schelhammer_und_schattera_ag, bawag_psk_ag, bks_bank_ag, brull_kallmus_bank_ag, btv_vier_lander_bank, capital_bank_grawe_gruppe_ag, deutsche_bank_ag, dolomitenbank, easybank_ag, erste_bank_und_sparkassen, hypo_alpeadriabank_international_ag, hypo_noe_lb_fur_niederosterreich_u_wien, hypo_oberosterreich_salzburg_steiermark, hypo_tirol_bank_ag, hypo_vorarlberg_bank_ag, hypo_bank_burgenland_aktiengesellschaft, marchfelder_bank, oberbank_ag, raiffeisen_bankengruppe_osterreich, schoellerbank_ag, sparda_bank_wien, volksbank_gruppe, volkskreditbank_ag, or vr_bank_braunau.
PaymentMethodDetailsPaymentRecordIdealBank
The customer’s bank. Can be one of abn_amro, adyen, asn_bank, bunq, buut, finom, handelsbanken, ing, knab, mollie, moneyou, n26, nn, rabobank, regiobank, revolut, sns_bank, triodos_bank, van_lanschot, or yoursafe.
PaymentMethodDetailsPaymentRecordIdealBic
The Bank Identifier Code of the customer’s bank.
PaymentMethodDetailsPaymentRecordSofortPreferredLanguage
Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of de, en, es, fr, it, nl, or pl.
PaymentMethodDetailsPaymentRecordUsBankAccountAccountHolderType
The type of entity that holds the account. This can be either ‘individual’ or ‘company’.
PaymentMethodDetailsPaymentRecordUsBankAccountAccountType
The type of the bank account. This can be either ‘checking’ or ‘savings’.
PaymentMethodDetailsSofortPreferredLanguage
Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of de, en, es, fr, it, nl, or pl
PaymentMethodDetailsUsBankAccountAccountHolderType
Account holder type: individual or company.
PaymentMethodDetailsUsBankAccountAccountType
Account type: checkings or savings. Defaults to checking if omitted.
PaymentMethodDomainResourcePaymentMethodStatusStatus
The status of the payment method on the domain.
PaymentMethodEpsBank
The customer’s bank. Should be one of arzte_und_apotheker_bank, austrian_anadi_bank_ag, bank_austria, bankhaus_carl_spangler, bankhaus_schelhammer_und_schattera_ag, bawag_psk_ag, bks_bank_ag, brull_kallmus_bank_ag, btv_vier_lander_bank, capital_bank_grawe_gruppe_ag, deutsche_bank_ag, dolomitenbank, easybank_ag, erste_bank_und_sparkassen, hypo_alpeadriabank_international_ag, hypo_noe_lb_fur_niederosterreich_u_wien, hypo_oberosterreich_salzburg_steiermark, hypo_tirol_bank_ag, hypo_vorarlberg_bank_ag, hypo_bank_burgenland_aktiengesellschaft, marchfelder_bank, oberbank_ag, raiffeisen_bankengruppe_osterreich, schoellerbank_ag, sparda_bank_wien, volksbank_gruppe, volkskreditbank_ag, or vr_bank_braunau.
PaymentMethodFpxAccountHolderType
Account holder type, if provided. Can be one of individual or company.
PaymentMethodFpxBank
The customer’s bank, if provided. Can be one of affin_bank, agrobank, alliance_bank, ambank, bank_islam, bank_muamalat, bank_rakyat, bsn, cimb, hong_leong_bank, hsbc, kfh, maybank2u, ocbc, public_bank, rhb, standard_chartered, uob, deutsche_bank, maybank2e, pb_enterprise, or bank_of_china.
PaymentMethodIdealBank
The customer’s bank, if provided. Can be one of abn_amro, adyen, asn_bank, bunq, buut, finom, handelsbanken, ing, knab, mollie, moneyou, n26, nn, rabobank, regiobank, revolut, sns_bank, triodos_bank, van_lanschot, or yoursafe.
PaymentMethodIdealBic
The Bank Identifier Code of the customer’s bank, if the bank was provided.
PaymentMethodInteracPresentReadMethod
How card details were read in this transaction.
PaymentMethodKrCardBrand
The local credit or debit card brand.
PaymentMethodNaverPayFunding
Whether to fund this transaction with Naver Pay points or a card.
PaymentMethodOptionsAffirmCaptureMethod
Controls when the funds will be captured from the customer’s account.
PaymentMethodOptionsAffirmSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsAfterpayClearpayCaptureMethod
Controls when the funds will be captured from the customer’s account.
PaymentMethodOptionsAfterpayClearpaySetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsAlipaySetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsAlmaCaptureMethod
Controls when the funds will be captured from the customer’s account.
PaymentMethodOptionsAmazonPayCaptureMethod
Controls when the funds will be captured from the customer’s account.
PaymentMethodOptionsAmazonPaySetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsBancontactPreferredLanguage
Preferred language of the Bancontact authorization page that the customer is redirected to.
PaymentMethodOptionsBancontactSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsBillieCaptureMethod
Controls when the funds will be captured from the customer’s account.
PaymentMethodOptionsBoletoSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsCardMandateOptionsAmountType
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
PaymentMethodOptionsCardMandateOptionsInterval
Specifies payment frequency. One of day, week, month, year, or sporadic.
PaymentMethodOptionsCardMandateOptionsSupportedTypes
Specifies the type of mandates supported. Possible values are india.
PaymentMethodOptionsCardPresentCaptureMethod
Controls when the funds will be captured from the customer’s account.
PaymentMethodOptionsCardPresentRoutingRequestedPriority
Requested routing priority
PaymentMethodOptionsCashappCaptureMethod
Controls when the funds will be captured from the customer’s account.
PaymentMethodOptionsCashappSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsCryptoSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsCustomerBalanceBankTransferRequestedAddressTypes
List of address types that should be returned in the financial_addresses response. If not specified, all valid types will be returned.
PaymentMethodOptionsCustomerBalanceBankTransferType
The bank transfer type that this PaymentIntent is allowed to use for funding Permitted values include: eu_bank_transfer, gb_bank_transfer, jp_bank_transfer, mx_bank_transfer, or us_bank_transfer.
PaymentMethodOptionsCustomerBalanceEuBankAccountCountry
The desired country code of the bank account information. Permitted values include: DE, FR, IE, or NL.
PaymentMethodOptionsCustomerBalanceFundingType
The funding method type to be used when there are not enough funds in the customer balance. Permitted values include: bank_transfer.
PaymentMethodOptionsCustomerBalanceSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsFpxSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsGiropaySetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsGrabpaySetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsIdealSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsKlarnaCaptureMethod
Controls when the funds will be captured from the customer’s account.
PaymentMethodOptionsKlarnaSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsKonbiniSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsKrCardCaptureMethod
Controls when the funds will be captured from the customer’s account.
PaymentMethodOptionsKrCardSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsMandateOptionsPixAmountIncludesIof
Determines if the amount includes the IOF tax.
PaymentMethodOptionsMandateOptionsPixAmountType
Type of amount.
PaymentMethodOptionsMandateOptionsPixPaymentSchedule
Schedule at which the future payments will be charged.
PaymentMethodOptionsMandateOptionsUpiAmountType
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
PaymentMethodOptionsMbWaySetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsMultibancoSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsOxxoSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsP24SetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsPaynowSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsPaypalCaptureMethod
Controls when the funds will be captured from the customer’s account.
PaymentMethodOptionsPaypalSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsPixAmountIncludesIof
Determines if the amount includes the IOF tax.
PaymentMethodOptionsPixSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsPromptpaySetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsRevolutPayCaptureMethod
Controls when the funds will be captured from the customer’s account.
PaymentMethodOptionsRevolutPaySetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsSatispayCaptureMethod
Controls when the funds will be captured from the customer’s account.
PaymentMethodOptionsSofortPreferredLanguage
Preferred language of the SOFORT authorization page that the customer is redirected to.
PaymentMethodOptionsSofortSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsTwintSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsUpiSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsUsBankAccountMandateOptionsCollectionMethod
Mandate collection method
PaymentMethodOptionsWechatPayClient
The client type that the end customer will pay from
PaymentMethodOptionsWechatPaySetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodOptionsZipSetupFutureUsage
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
PaymentMethodP24Bank
The customer’s bank, if provided.
PaymentMethodType
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
PaymentMethodUsBankAccountAccountHolderType
Account holder type: individual or company.
PaymentMethodUsBankAccountAccountType
Account type: checkings or savings. Defaults to checking if omitted.
PaymentMethodUsBankAccountBlockedNetworkCode
The ACH network code that resulted in this block.
PaymentMethodUsBankAccountBlockedReason
The reason why this PaymentMethod’s fingerprint has been blocked
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodAmazonPayDetailsResourceFundingType
funding type of the underlying payment method.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsBrand
Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsFunding
Card funding type. Can be credit, debit, prepaid, or unknown.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsNetwork
Identifies which network this charge was processed on. Can be amex, cartes_bancaires, diners, discover, eftpos_au, interac, jcb, link, mastercard, unionpay, visa, or unknown.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceChecksAddressLine1Check
If you provide a value for address.line1, the check result is one of pass, fail, unavailable, or unchecked.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceChecksAddressPostalCodeCheck
If you provide a address postal code, the check result is one of pass, fail, unavailable, or unchecked.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceChecksCvcCheck
If you provide a CVC, the check results is one of pass, fail, unavailable, or unchecked.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceInstallmentPlanInterval
For fixed_count installment plans, this is the interval between installment payments your customer will make to their credit card. One of month.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceInstallmentPlanType
Type of installment plan, one of fixed_count, revolving, or bonus.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceThreeDSecureAuthenticationFlow
For authenticated transactions: Indicates how the issuing bank authenticated the customer.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceThreeDSecureElectronicCommerceIndicator
The Electronic Commerce Indicator (ECI). A protocol-level field indicating what degree of authentication was performed.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceThreeDSecureExemptionIndicator
The exemption requested via 3DS and accepted by the issuer at authentication time.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceThreeDSecureResult
Indicates the outcome of 3D Secure authentication.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceThreeDSecureResultReason
Additional information about why 3D Secure succeeded or failed, based on the result.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceThreeDSecureVersion
The version of 3D Secure that was used.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsStoredCredentialUsage
The transaction type that was passed for an off-session, Merchant-Initiated transaction, one of recurring or unscheduled.
PaymentsPrimitivesPaymentRecordsResourcePaymentMethodKonbiniDetailsResourceStoreChain
The name of the convenience store chain where the payment was completed.
PaymentsPrimitivesPaymentRecordsResourceProcessorDetailsType
The processor used for this payment attempt.
PaypalSellerProtectionDisputeCategories
An array of conditions that are covered for the transaction, if applicable.
PaypalSellerProtectionStatus
Indicates whether the transaction is eligible for PayPal’s seller protection.
RevolutPayUnderlyingPaymentMethodFundingDetailsType
funding type of the underlying payment method.
SourceAllowRedisplay
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.
SourceTransactionType
The type of source this transaction is attached to.
SourceType
The type of the source. The type is a payment method, one of ach_credit_transfer, ach_debit, alipay, bancontact, card, card_present, eps, giropay, ideal, multibanco, klarna, p24, sepa_debit, sofort, three_d_secure, or wechat. An additional hash is included on the source with a name matching this value. It contains additional information specific to the payment method used.
ThreeDSecureDetailsChargeAuthenticationFlow
For authenticated transactions: how the customer was authenticated by the issuing bank.
ThreeDSecureDetailsChargeElectronicCommerceIndicator
The Electronic Commerce Indicator (ECI). A protocol-level field indicating what degree of authentication was performed.
ThreeDSecureDetailsChargeExemptionIndicator
The exemption requested via 3DS and accepted by the issuer at authentication time.
ThreeDSecureDetailsChargeResult
Indicates the outcome of 3D Secure authentication.
ThreeDSecureDetailsChargeResultReason
Additional information about why 3D Secure succeeded or failed based on the result.
ThreeDSecureDetailsChargeVersion
The version of 3D Secure that was used.
UsBankAccountNetworksSupported
All supported networks.