#[non_exhaustive]pub enum UpdateAccountCardAccountType {
Checking,
Futsu,
Savings,
Toza,
Unknown(String),
}Expand description
The bank account type.
This can only be checking or savings in most countries.
In Japan, this can only be futsu or toza.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Checking
Futsu
Savings
Toza
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations