CreateConfirmationToken

Struct CreateConfirmationToken 

pub struct CreateConfirmationToken { /* private fields */ }
Creates a test mode Confirmation Token server side for your integration tests.

Implementations

Source

impl CreateConfirmationToken

pub fn new() -> Self

Construct a new CreateConfirmationToken.

pub fn expand(self, expand: impl Into<Vec<String>>) -> Self

Specifies which fields in the response should be expanded.

pub fn payment_method(self, payment_method: impl Into<String>) -> Self

ID of an existing PaymentMethod.

pub fn payment_method_data( self, payment_method_data: impl Into<CreateConfirmationTokenPaymentMethodData>, ) -> Self

If provided, this hash will be used to create a PaymentMethod.

pub fn payment_method_options( self, payment_method_options: impl Into<CreateConfirmationTokenPaymentMethodOptions>, ) -> Self

Payment-method-specific configuration for this ConfirmationToken.

pub fn return_url(self, return_url: impl Into<String>) -> Self

Return URL used to confirm the Intent.

pub fn setup_future_usage( self, setup_future_usage: impl Into<ConfirmationTokenSetupFutureUsage>, ) -> Self

Indicates that you intend to make future payments with this ConfirmationToken’s payment method.

The presence of this property will attach the payment method to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.

pub fn shipping( self, shipping: impl Into<CreateConfirmationTokenShipping>, ) -> Self

Shipping information for this ConfirmationToken.

Source

impl CreateConfirmationToken

pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response.

pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response, blocking until completion.