pub struct CreateConfirmationTokenPaymentMethodDataBacsDebit {
pub account_number: Option<String>,
pub sort_code: Option<String>,
}Expand description
If this is a bacs_debit PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.
Fields
account_number: Option<String>Account number of the bank account that the funds will be debited from.
sort_code: Option<String>Sort code of the bank account. (e.g., 10-20-30)
Implementations