pub struct CreateConfirmationTokenPaymentMethodDataNzBankAccount {
pub account_holder_name: Option<String>,
pub account_number: String,
pub bank_code: String,
pub branch_code: String,
pub reference: Option<String>,
pub suffix: String,
}Expand description
If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.
Fields
account_holder_name: Option<String>The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
account_number: StringThe account number for the bank account.
bank_code: StringThe numeric code for the bank account’s bank.
branch_code: StringThe numeric code for the bank account’s bank branch.
reference: Option<String>suffix: StringThe suffix of the bank account number.
Implementations