CreateConfirmationTokenPaymentMethodDataUpiMandateOptions

Struct CreateConfirmationTokenPaymentMethodDataUpiMandateOptions 

pub struct CreateConfirmationTokenPaymentMethodDataUpiMandateOptions {
    pub amount: Option<i64>,
    pub amount_type: Option<CreateConfirmationTokenPaymentMethodDataUpiMandateOptionsAmountType>,
    pub description: Option<String>,
    pub end_date: Option<Timestamp>,
}
Configuration options for setting up an eMandate

Fields

amount: Option<i64>

Amount to be charged for future payments.

amount_type: Option<CreateConfirmationTokenPaymentMethodDataUpiMandateOptionsAmountType>

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.

description: Option<String>

A description of the mandate or subscription that is meant to be displayed to the customer.

end_date: Option<Timestamp>

End date of the mandate or subscription.

Implementations