#[non_exhaustive]pub enum CreatePaymentLinkLineItemsPriceDataTaxBehavior {
Exclusive,
Inclusive,
Unspecified,
Unknown(String),
}Expand description
Only required if a default tax behavior was not provided in the Stripe Tax settings.
Specifies whether the price is considered inclusive of taxes or exclusive of taxes.
One of inclusive, exclusive, or unspecified.
Once specified as either inclusive or exclusive, it cannot be changed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Exclusive
Inclusive
Unspecified
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations