#[non_exhaustive]pub enum CreatePaymentLinkPaymentIntentDataSetupFutureUsage {
OffSession,
OnSession,
Unknown(String),
}Expand description
Indicates that you intend to make future payments with the payment method collected by this Checkout Session.
When setting this to on_session, Checkout will show a notice to the customer that their payment details will be saved.
When setting this to off_session, Checkout will show a notice to the customer that their payment details will be saved and used for future payments.
If a Customer has been provided or Checkout creates a new Customer,Checkout will attach the payment method to the Customer.
If Checkout does not create a Customer, the payment method is not attached to a Customer. To reuse the payment method, you can retrieve it from the Checkout Session’s PaymentIntent.
When processing card payments, Checkout also uses setup_future_usage to dynamically optimize your payment flow and comply with regional legislation and network rules, such as SCA.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
OffSession
OnSession
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations