#[non_exhaustive]pub enum CreatePaymentLinkSubscriptionDataTrialSettingsEndBehaviorMissingPaymentMethod {
Cancel,
CreateInvoice,
Pause,
Unknown(String),
}Expand description
Indicates how the subscription should change when the trial ends if the user did not provide a payment method.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Cancel
CreateInvoice
Pause
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations