#[non_exhaustive]pub enum UpdatePaymentLinkPaymentMethodCollection {
Always,
IfRequired,
Unknown(String),
}Expand description
Specify whether Checkout should collect a payment method.
When set to if_required, Checkout will not collect a payment method when the total due for the session is 0.This may occur if the Checkout Session includes a free trial or a discount.
Can only be set in subscription mode. Defaults to always.
If you’d like information on how to collect a payment method outside of Checkout, read the guide on configuring subscriptions with a free trial.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Always
IfRequired
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations