pub struct CreatePaymentLinkCustomFields {
pub dropdown: Option<CustomFieldDropdownParam>,
pub key: String,
pub label: CreatePaymentLinkCustomFieldsLabel,
pub numeric: Option<CreatePaymentLinkCustomFieldsNumeric>,
pub optional: Option<bool>,
pub text: Option<CreatePaymentLinkCustomFieldsText>,
pub type_: CreatePaymentLinkCustomFieldsType,
}Expand description
Collect additional information from your customer using custom fields.
Up to 3 fields are supported.
You can’t set this parameter if ui_mode is custom.
Fields
dropdown: Option<CustomFieldDropdownParam>Configuration for type=dropdown fields.
key: StringString of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.
label: CreatePaymentLinkCustomFieldsLabelThe label for the field, displayed to the customer.
numeric: Option<CreatePaymentLinkCustomFieldsNumeric>Configuration for type=numeric fields.
optional: Option<bool>Whether the customer is required to complete the field before completing the Checkout Session.
Defaults to false.
text: Option<CreatePaymentLinkCustomFieldsText>Configuration for type=text fields.
type_: CreatePaymentLinkCustomFieldsTypeThe type of the field.
Implementations
Sourceimpl CreatePaymentLinkCustomFields
impl CreatePaymentLinkCustomFields
pub fn new( key: impl Into<String>, label: impl Into<CreatePaymentLinkCustomFieldsLabel>, type_: impl Into<CreatePaymentLinkCustomFieldsType>, ) -> Self