pub struct CreatePaymentLinkCustomFieldsLabel {
pub custom: String,
pub type_: CreatePaymentLinkCustomFieldsLabelType,
}Expand description
The label for the field, displayed to the customer.
Fields
custom: StringCustom text for the label, displayed to the customer. Up to 50 characters.
type_: CreatePaymentLinkCustomFieldsLabelTypeThe type of the label.
Implementations