pub struct CreatePaymentLinkInvoiceCreationInvoiceData {
pub account_tax_ids: Option<Vec<String>>,
pub custom_fields: Option<Vec<CustomFieldParams>>,
pub description: Option<String>,
pub footer: Option<String>,
pub issuer: Option<CreatePaymentLinkInvoiceCreationInvoiceDataIssuer>,
pub metadata: Option<HashMap<String, String>>,
pub rendering_options: Option<CreatePaymentLinkInvoiceCreationInvoiceDataRenderingOptions>,
}Expand description
Invoice PDF configuration.
Fields
account_tax_ids: Option<Vec<String>>The account tax IDs associated with the invoice.
custom_fields: Option<Vec<CustomFieldParams>>Default custom fields to be displayed on invoices for this customer.
description: Option<String>An arbitrary string attached to the object. Often useful for displaying to users.
Default footer to be displayed on invoices for this customer.
issuer: Option<CreatePaymentLinkInvoiceCreationInvoiceDataIssuer>The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
metadata: Option<HashMap<String, String>>Set of key-value pairs that you can attach to an object.
This can be useful for storing additional information about the object in a structured format.
Individual keys can be unset by posting an empty value to them.
All keys can be unset by posting an empty value to metadata.
rendering_options: Option<CreatePaymentLinkInvoiceCreationInvoiceDataRenderingOptions>Default options for invoice PDF rendering for this customer.
Implementations