pub struct CreatePaymentLinkInvoiceCreationInvoiceDataIssuer {
pub account: Option<String>,
pub type_: CreatePaymentLinkInvoiceCreationInvoiceDataIssuerType,
}Expand description
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
Fields
account: Option<String>The connected account being referenced when type is account.
type_: CreatePaymentLinkInvoiceCreationInvoiceDataIssuerTypeType of the account referenced in the request.
Implementations
Sourceimpl CreatePaymentLinkInvoiceCreationInvoiceDataIssuer
impl CreatePaymentLinkInvoiceCreationInvoiceDataIssuer
pub fn new( type_: impl Into<CreatePaymentLinkInvoiceCreationInvoiceDataIssuerType>, ) -> Self