pub struct CreatePaymentLinkLineItems {
pub adjustable_quantity: Option<AdjustableQuantityParams>,
pub price: Option<String>,
pub price_data: Option<CreatePaymentLinkLineItemsPriceData>,
pub quantity: u64,
}Expand description
The line items representing what is being sold. Each line item represents an item being sold. Up to 20 line items are supported.
Fields
adjustable_quantity: Option<AdjustableQuantityParams>When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
price: Option<String>price_data: Option<CreatePaymentLinkLineItemsPriceData>Data used to generate a new Price object inline.
One of price or price_data is required.
quantity: u64The quantity of the line item being purchased.
Implementations