pub struct CreatePaymentLinkLineItemsPriceData {
pub currency: Currency,
pub product: Option<String>,
pub product_data: Option<CreatePaymentLinkLineItemsPriceDataProductData>,
pub recurring: Option<CreatePaymentLinkLineItemsPriceDataRecurring>,
pub tax_behavior: Option<CreatePaymentLinkLineItemsPriceDataTaxBehavior>,
pub unit_amount: Option<i64>,
pub unit_amount_decimal: Option<String>,
}Expand description
Data used to generate a new Price object inline.
One of price or price_data is required.
Fields
currency: CurrencyThree-letter ISO currency code, in lowercase. Must be a supported currency.
product: Option<String>product_data: Option<CreatePaymentLinkLineItemsPriceDataProductData>Data used to generate a new Product object inline.
One of product or product_data is required.
recurring: Option<CreatePaymentLinkLineItemsPriceDataRecurring>The recurring components of a price such as interval and interval_count.
tax_behavior: Option<CreatePaymentLinkLineItemsPriceDataTaxBehavior>Only required if a default tax behavior was not provided in the Stripe Tax settings.
Specifies whether the price is considered inclusive of taxes or exclusive of taxes.
One of inclusive, exclusive, or unspecified.
Once specified as either inclusive or exclusive, it cannot be changed.
unit_amount: Option<i64>A non-negative integer in cents (or local equivalent) representing how much to charge.
One of unit_amount or unit_amount_decimal is required.
unit_amount_decimal: Option<String>Same as unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Only one of unit_amount and unit_amount_decimal can be set.
Implementations