CreatePaymentLinkLineItemsPriceDataProductData

Struct CreatePaymentLinkLineItemsPriceDataProductData 

pub struct CreatePaymentLinkLineItemsPriceDataProductData {
    pub description: Option<String>,
    pub images: Option<Vec<String>>,
    pub metadata: Option<HashMap<String, String>>,
    pub name: String,
    pub tax_code: Option<String>,
    pub unit_label: Option<String>,
}
Data used to generate a new Product object inline. One of product or product_data is required.

Fields

description: Option<String>

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.

images: Option<Vec<String>>

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.

metadata: Option<HashMap<String, String>>

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.

name: String

The product’s name, meant to be displayable to the customer.

tax_code: Option<String>

A tax code ID.

unit_label: Option<String>

A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.

Implementations