pub struct CreatePaymentLinkSubscriptionData {
pub description: Option<String>,
pub invoice_settings: Option<CreatePaymentLinkSubscriptionDataInvoiceSettings>,
pub metadata: Option<HashMap<String, String>>,
pub trial_period_days: Option<u32>,
pub trial_settings: Option<CreatePaymentLinkSubscriptionDataTrialSettings>,
}Expand description
When creating a subscription, the specified configuration data will be used.
There must be at least one line item with a recurring price to use subscription_data.
Fields
description: Option<String>The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
invoice_settings: Option<CreatePaymentLinkSubscriptionDataInvoiceSettings>All invoices will be billed using the specified settings.
metadata: Option<HashMap<String, String>>Set of key-value pairs that will declaratively set metadata on Subscriptions generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.
trial_period_days: Option<u32>Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.
trial_settings: Option<CreatePaymentLinkSubscriptionDataTrialSettings>Settings related to subscription trials.
Implementations