pub struct CreatePaymentLinkSubscriptionDataInvoiceSettings {
pub issuer: Option<CreatePaymentLinkSubscriptionDataInvoiceSettingsIssuer>,
}Expand description
All invoices will be billed using the specified settings.
Fields
issuer: Option<CreatePaymentLinkSubscriptionDataInvoiceSettingsIssuer>The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
Implementations