pub struct CreatePaymentLinkSubscriptionDataInvoiceSettingsIssuer {
pub account: Option<String>,
pub type_: CreatePaymentLinkSubscriptionDataInvoiceSettingsIssuerType,
}Expand description
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
Fields
account: Option<String>The connected account being referenced when type is account.
type_: CreatePaymentLinkSubscriptionDataInvoiceSettingsIssuerTypeType of the account referenced in the request.
Implementations
Sourceimpl CreatePaymentLinkSubscriptionDataInvoiceSettingsIssuer
impl CreatePaymentLinkSubscriptionDataInvoiceSettingsIssuer
pub fn new( type_: impl Into<CreatePaymentLinkSubscriptionDataInvoiceSettingsIssuerType>, ) -> Self