pub struct CreatePaymentLinkTransferData {
pub amount: Option<i64>,
pub destination: String,
}Expand description
The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to.
Fields
amount: Option<i64>The amount that will be transferred automatically when a charge succeeds.
destination: StringIf specified, successful charges will be attributed to the destination
account for tax reporting, and the funds from charges will be transferred
to the destination account. The ID of the resulting transfer will be
returned on the successful charge’s transfer field.
Implementations