pub struct CustomTextParam {
pub after_submit: Option<CustomTextPositionParam>,
pub shipping_address: Option<CustomTextPositionParam>,
pub submit: Option<CustomTextPositionParam>,
pub terms_of_service_acceptance: Option<CustomTextPositionParam>,
}Fields
after_submit: Option<CustomTextPositionParam>Custom text that should be displayed after the payment confirmation button.
shipping_address: Option<CustomTextPositionParam>Custom text that should be displayed alongside shipping address collection.
submit: Option<CustomTextPositionParam>Custom text that should be displayed alongside the payment confirmation button.
terms_of_service_acceptance: Option<CustomTextPositionParam>Custom text that should be displayed in place of the default terms of service agreement text.
Implementations