CreatePaymentMethodCard

Enum CreatePaymentMethodCard 

pub enum CreatePaymentMethodCard {
    CardDetailsParams(CreatePaymentMethodCardDetailsParams),
    TokenParams(CreatePaymentMethodTokenParams),
}
If this is a card PaymentMethod, this hash contains the user’s card details. For backwards compatibility, you can alternatively provide a Stripe token (e.g., for Apple Pay, Amex Express Checkout, or legacy Checkout) into the card hash with format card: {token: "tok_visa"}. When providing a card number, you must meet the requirements for PCI compliance. We strongly recommend using Stripe.js instead of interacting with this API directly.

Variants