pub struct CreatePaymentMethodCardDetailsParams {
pub cvc: Option<String>,
pub exp_month: i64,
pub exp_year: i64,
pub networks: Option<CreatePaymentMethodCardDetailsParamsNetworks>,
pub number: String,
}Expand description
If this is a card PaymentMethod, this hash contains the user’s card details.
For backwards compatibility, you can alternatively provide a Stripe token (e.g., for Apple Pay, Amex Express Checkout, or legacy Checkout) into the card hash with format card: {token: "tok_visa"}.
When providing a card number, you must meet the requirements for PCI compliance.
We strongly recommend using Stripe.js instead of interacting with this API directly.
Fields
cvc: Option<String>The card’s CVC. It is highly recommended to always include this value.
exp_month: i64Two-digit number representing the card’s expiration month.
exp_year: i64Four-digit number representing the card’s expiration year.
networks: Option<CreatePaymentMethodCardDetailsParamsNetworks>Contains information about card networks used to process the payment.
number: StringThe card number, as a string without any separators.
Implementations