pub struct CreatePaymentMethodCardDetailsParamsNetworks {
pub preferred: Option<CreatePaymentMethodCardDetailsParamsNetworksPreferred>,
}Expand description
Contains information about card networks used to process the payment.
Fields
preferred: Option<CreatePaymentMethodCardDetailsParamsNetworksPreferred>The customer’s preferred card network for co-branded cards.
Supports cartes_bancaires, mastercard, or visa.
Selection of a network that does not apply to the card will be stored as invalid_preference on the card.
Implementations