pub struct ListPaymentMethod { /* private fields */ }Expand description
Returns a list of all PaymentMethods.
Implementations
Sourceimpl ListPaymentMethod
impl ListPaymentMethod
Sourcepub fn allow_redisplay(
self,
allow_redisplay: impl Into<PaymentMethodAllowRedisplay>,
) -> Self
pub fn allow_redisplay( self, allow_redisplay: impl Into<PaymentMethodAllowRedisplay>, ) -> Self
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.
Sourcepub fn customer(self, customer: impl Into<String>) -> Self
pub fn customer(self, customer: impl Into<String>) -> Self
The ID of the customer whose PaymentMethods will be retrieved.
Sourcepub fn customer_account(self, customer_account: impl Into<String>) -> Self
pub fn customer_account(self, customer_account: impl Into<String>) -> Self
The ID of the Account whose PaymentMethods will be retrieved.
Sourcepub fn ending_before(self, ending_before: impl Into<String>) -> Self
pub fn ending_before(self, ending_before: impl Into<String>) -> Self
A cursor for use in pagination.
ending_before is an object ID that defines your place in the list.
For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list.
Sourcepub fn expand(self, expand: impl Into<Vec<String>>) -> Self
pub fn expand(self, expand: impl Into<Vec<String>>) -> Self
Specifies which fields in the response should be expanded.
Sourcepub fn limit(self, limit: impl Into<i64>) -> Self
pub fn limit(self, limit: impl Into<i64>) -> Self
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
Sourcepub fn starting_after(self, starting_after: impl Into<String>) -> Self
pub fn starting_after(self, starting_after: impl Into<String>) -> Self
A cursor for use in pagination.
starting_after is an object ID that defines your place in the list.
For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list.
Sourcepub fn type_(self, type_: impl Into<ListPaymentMethodType>) -> Self
pub fn type_(self, type_: impl Into<ListPaymentMethodType>) -> Self
Filters the list by the object type field.
Unfiltered, the list returns all payment method types except custom.
If your integration expects only one type of payment method in the response, specify that type value in the request to reduce your payload.
Sourceimpl ListPaymentMethod
impl ListPaymentMethod
Sourcepub async fn send<C: StripeClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response.
Sourcepub fn send_blocking<C: StripeBlockingClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response, blocking until completion.
pub fn paginate(&self) -> ListPaginator<List<PaymentMethod>>