pub struct CreatePaymentMethodConfigurationAcssDebit {
pub display_preference: Option<CreatePaymentMethodConfigurationAcssDebitDisplayPreference>,
}Expand description
Canadian pre-authorized debit payments, check this page for more details like country availability.
Fields
display_preference: Option<CreatePaymentMethodConfigurationAcssDebitDisplayPreference>Whether or not the payment method should be displayed.
Implementations