pub struct CreatePaymentMethodConfigurationAfterpayClearpay {
pub display_preference: Option<CreatePaymentMethodConfigurationAfterpayClearpayDisplayPreference>,
}Expand description
Afterpay gives your customers a way to pay for purchases in installments, check this page for more details like country availability. Afterpay is particularly popular among businesses selling fashion, beauty, and sports products.
Fields
display_preference: Option<CreatePaymentMethodConfigurationAfterpayClearpayDisplayPreference>Whether or not the payment method should be displayed.
Implementations