pub struct CreatePaymentMethodConfigurationAlipay {
pub display_preference: Option<CreatePaymentMethodConfigurationAlipayDisplayPreference>,
}Expand description
Alipay is a digital wallet in China that has more than a billion active users worldwide. Alipay users can pay on the web or on a mobile device using login credentials or their Alipay app. Alipay has a low dispute rate and reduces fraud by authenticating payments using the customer’s login credentials. Check this page for more details.
Fields
display_preference: Option<CreatePaymentMethodConfigurationAlipayDisplayPreference>Whether or not the payment method should be displayed.
Implementations