pub struct CreatePaymentMethodConfigurationApplePayDisplayPreference {
pub preference: Option<CreatePaymentMethodConfigurationApplePayDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<CreatePaymentMethodConfigurationApplePayDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations