pub struct CreatePaymentMethodConfigurationApplePayLater {
pub display_preference: Option<CreatePaymentMethodConfigurationApplePayLaterDisplayPreference>,
}Expand description
Apple Pay Later, a payment method for customers to buy now and pay later, gives your customers a way to split purchases into four installments across six weeks.
Fields
display_preference: Option<CreatePaymentMethodConfigurationApplePayLaterDisplayPreference>Whether or not the payment method should be displayed.
Implementations