pub struct CreatePaymentMethodConfigurationBacsDebit {
pub display_preference: Option<CreatePaymentMethodConfigurationBacsDebitDisplayPreference>,
}Expand description
Stripe users in the UK can accept Bacs Direct Debit payments from customers with a UK bank account, check this page for more details.
Fields
display_preference: Option<CreatePaymentMethodConfigurationBacsDebitDisplayPreference>Whether or not the payment method should be displayed.
Implementations