pub struct CreatePaymentMethodConfigurationBancontact {
pub display_preference: Option<CreatePaymentMethodConfigurationBancontactDisplayPreference>,
}Expand description
Bancontact is the most popular online payment method in Belgium, with over 15 million cards in circulation. Customers use a Bancontact card or mobile app linked to a Belgian bank account to make online payments that are secure, guaranteed, and confirmed immediately. Check this page for more details.
Fields
display_preference: Option<CreatePaymentMethodConfigurationBancontactDisplayPreference>Whether or not the payment method should be displayed.
Implementations