pub struct CreatePaymentMethodConfigurationBillieDisplayPreference {
pub preference: Option<CreatePaymentMethodConfigurationBillieDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<CreatePaymentMethodConfigurationBillieDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations