pub struct CreatePaymentMethodConfigurationBlikDisplayPreference {
pub preference: Option<CreatePaymentMethodConfigurationBlikDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<CreatePaymentMethodConfigurationBlikDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations