pub struct CreatePaymentMethodConfigurationCard {
pub display_preference: Option<CreatePaymentMethodConfigurationCardDisplayPreference>,
}Expand description
Cards are a popular way for consumers and businesses to pay online or in person. Stripe supports global and local card networks.
Fields
display_preference: Option<CreatePaymentMethodConfigurationCardDisplayPreference>Whether or not the payment method should be displayed.
Implementations