pub struct CreatePaymentMethodConfigurationCardDisplayPreference {
pub preference: Option<CreatePaymentMethodConfigurationCardDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<CreatePaymentMethodConfigurationCardDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations