pub struct CreatePaymentMethodConfigurationCartesBancairesDisplayPreference {
pub preference: Option<CreatePaymentMethodConfigurationCartesBancairesDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<CreatePaymentMethodConfigurationCartesBancairesDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations