pub struct CreatePaymentMethodConfigurationCashapp {
pub display_preference: Option<CreatePaymentMethodConfigurationCashappDisplayPreference>,
}Expand description
Cash App is a popular consumer app in the US that allows customers to bank, invest, send, and receive money using their digital wallet. Check this page for more details.
Fields
display_preference: Option<CreatePaymentMethodConfigurationCashappDisplayPreference>Whether or not the payment method should be displayed.
Implementations