pub struct CreatePaymentMethodConfigurationCashappDisplayPreference {
pub preference: Option<CreatePaymentMethodConfigurationCashappDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<CreatePaymentMethodConfigurationCashappDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations