pub struct CreatePaymentMethodConfigurationEps {
pub display_preference: Option<CreatePaymentMethodConfigurationEpsDisplayPreference>,
}Expand description
EPS is an Austria-based payment method that allows customers to complete transactions online using their bank credentials. EPS is supported by all Austrian banks and is accepted by over 80% of Austrian online retailers. Check this page for more details.
Fields
display_preference: Option<CreatePaymentMethodConfigurationEpsDisplayPreference>Whether or not the payment method should be displayed.
Implementations