pub struct CreatePaymentMethodConfigurationEpsDisplayPreference {
pub preference: Option<CreatePaymentMethodConfigurationEpsDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<CreatePaymentMethodConfigurationEpsDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations