pub struct CreatePaymentMethodConfigurationFrMealVoucherConecsDisplayPreference {
pub preference: Option<CreatePaymentMethodConfigurationFrMealVoucherConecsDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<CreatePaymentMethodConfigurationFrMealVoucherConecsDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations