pub struct CreatePaymentMethodConfigurationIdeal {
pub display_preference: Option<CreatePaymentMethodConfigurationIdealDisplayPreference>,
}Expand description
iDEAL is a Netherlands-based payment method that allows customers to complete transactions online using their bank credentials. All major Dutch banks are members of Currence, the scheme that operates iDEAL, making it the most popular online payment method in the Netherlands with a share of online transactions close to 55%. Check this page for more details.
Fields
display_preference: Option<CreatePaymentMethodConfigurationIdealDisplayPreference>Whether or not the payment method should be displayed.
Implementations