pub struct CreatePaymentMethodConfigurationIdealDisplayPreference {
pub preference: Option<CreatePaymentMethodConfigurationIdealDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<CreatePaymentMethodConfigurationIdealDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations