pub struct CreatePaymentMethodConfigurationKlarna {
pub display_preference: Option<CreatePaymentMethodConfigurationKlarnaDisplayPreference>,
}Expand description
Klarna gives customers a range of payment options during checkout. Available payment options vary depending on the customer’s billing address and the transaction amount. These payment options make it convenient for customers to purchase items in all price ranges. Check this page for more details.
Fields
display_preference: Option<CreatePaymentMethodConfigurationKlarnaDisplayPreference>Whether or not the payment method should be displayed.
Implementations