pub struct CreatePaymentMethodConfigurationKlarnaDisplayPreference {
pub preference: Option<CreatePaymentMethodConfigurationKlarnaDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<CreatePaymentMethodConfigurationKlarnaDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations