pub struct CreatePaymentMethodConfigurationKonbini {
pub display_preference: Option<CreatePaymentMethodConfigurationKonbiniDisplayPreference>,
}Expand description
Konbini allows customers in Japan to pay for bills and online purchases at convenience stores with cash. Check this page for more details.
Fields
display_preference: Option<CreatePaymentMethodConfigurationKonbiniDisplayPreference>Whether or not the payment method should be displayed.
Implementations