pub struct CreatePaymentMethodConfigurationKonbiniDisplayPreference {
pub preference: Option<CreatePaymentMethodConfigurationKonbiniDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<CreatePaymentMethodConfigurationKonbiniDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations