pub struct CreatePaymentMethodConfigurationKrCard {
pub display_preference: Option<CreatePaymentMethodConfigurationKrCardDisplayPreference>,
}Expand description
Korean cards let users pay using locally issued cards from South Korea.
Fields
display_preference: Option<CreatePaymentMethodConfigurationKrCardDisplayPreference>Whether or not the payment method should be displayed.
Implementations