pub struct CreatePaymentMethodConfigurationNaverPay {
pub display_preference: Option<CreatePaymentMethodConfigurationNaverPayDisplayPreference>,
}Expand description
Naver Pay is a popular local wallet available in South Korea.
Fields
display_preference: Option<CreatePaymentMethodConfigurationNaverPayDisplayPreference>Whether or not the payment method should be displayed.
Implementations