pub struct CreatePaymentMethodConfigurationNzBankAccount {
pub display_preference: Option<CreatePaymentMethodConfigurationNzBankAccountDisplayPreference>,
}Expand description
Stripe users in New Zealand can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with a New Zeland bank account. Check this page for more details.
Fields
display_preference: Option<CreatePaymentMethodConfigurationNzBankAccountDisplayPreference>Whether or not the payment method should be displayed.
Implementations