pub struct CreatePaymentMethodConfigurationOxxo {
pub display_preference: Option<CreatePaymentMethodConfigurationOxxoDisplayPreference>,
}Expand description
OXXO is a Mexican chain of convenience stores with thousands of locations across Latin America and represents nearly 20% of online transactions in Mexico. OXXO allows customers to pay bills and online purchases in-store with cash. Check this page for more details.
Fields
display_preference: Option<CreatePaymentMethodConfigurationOxxoDisplayPreference>Whether or not the payment method should be displayed.
Implementations