pub struct CreatePaymentMethodConfigurationP24 {
pub display_preference: Option<CreatePaymentMethodConfigurationP24DisplayPreference>,
}Expand description
Przelewy24 is a Poland-based payment method aggregator that allows customers to complete transactions online using bank transfers and other methods. Bank transfers account for 30% of online payments in Poland and Przelewy24 provides a way for customers to pay with over 165 banks. Check this page for more details.
Fields
display_preference: Option<CreatePaymentMethodConfigurationP24DisplayPreference>Whether or not the payment method should be displayed.
Implementations