pub struct CreatePaymentMethodConfigurationPayByBankDisplayPreference {
pub preference: Option<CreatePaymentMethodConfigurationPayByBankDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<CreatePaymentMethodConfigurationPayByBankDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations