pub struct CreatePaymentMethodConfigurationPix {
pub display_preference: Option<CreatePaymentMethodConfigurationPixDisplayPreference>,
}Expand description
Pix is a payment method popular in Brazil. When paying with Pix, customers authenticate and approve payments by scanning a QR code in their preferred banking app. Check this page for more details.
Fields
display_preference: Option<CreatePaymentMethodConfigurationPixDisplayPreference>Whether or not the payment method should be displayed.
Implementations