pub struct CreatePaymentMethodConfigurationRevolutPay {
pub display_preference: Option<CreatePaymentMethodConfigurationRevolutPayDisplayPreference>,
}Expand description
Revolut Pay, developed by Revolut, a global finance app, is a digital wallet payment method. Revolut Pay uses the customer’s stored balance or cards to fund the payment, and offers the option for non-Revolut customers to save their details after their first purchase.
Fields
display_preference: Option<CreatePaymentMethodConfigurationRevolutPayDisplayPreference>Whether or not the payment method should be displayed.
Implementations