pub struct CreatePaymentMethodConfigurationRevolutPayDisplayPreference {
pub preference: Option<CreatePaymentMethodConfigurationRevolutPayDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<CreatePaymentMethodConfigurationRevolutPayDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations