pub struct CreatePaymentMethodConfigurationSamsungPayDisplayPreference {
pub preference: Option<CreatePaymentMethodConfigurationSamsungPayDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<CreatePaymentMethodConfigurationSamsungPayDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations