CreatePaymentMethodConfigurationSatispay

Struct CreatePaymentMethodConfigurationSatispay 

pub struct CreatePaymentMethodConfigurationSatispay {
    pub display_preference: Option<CreatePaymentMethodConfigurationSatispayDisplayPreference>,
}
Satispay is a single-use payment method where customers are required to authenticate their payment. Customers pay by being redirected from your website or app, authorizing the payment with Satispay, then returning to your website or app. You get immediate notification of whether the payment succeeded or failed.

Fields

display_preference: Option<CreatePaymentMethodConfigurationSatispayDisplayPreference>

Whether or not the payment method should be displayed.

Implementations