pub struct CreatePaymentMethodConfigurationSofortDisplayPreference {
pub preference: Option<CreatePaymentMethodConfigurationSofortDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<CreatePaymentMethodConfigurationSofortDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations