pub struct CreatePaymentMethodConfigurationTwint {
pub display_preference: Option<CreatePaymentMethodConfigurationTwintDisplayPreference>,
}Expand description
Twint is a payment method popular in Switzerland. It allows customers to pay using their mobile phone. Check this page for more details.
Fields
display_preference: Option<CreatePaymentMethodConfigurationTwintDisplayPreference>Whether or not the payment method should be displayed.
Implementations