pub struct CreatePaymentMethodConfigurationUsBankAccountDisplayPreference {
pub preference: Option<CreatePaymentMethodConfigurationUsBankAccountDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<CreatePaymentMethodConfigurationUsBankAccountDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations