pub struct CreatePaymentMethodConfigurationZip {
pub display_preference: Option<CreatePaymentMethodConfigurationZipDisplayPreference>,
}Expand description
Zip gives your customers a way to split purchases over a series of payments. Check this page for more details like country availability.
Fields
display_preference: Option<CreatePaymentMethodConfigurationZipDisplayPreference>Whether or not the payment method should be displayed.
Implementations