UpdatePaymentMethodConfiguration

Struct UpdatePaymentMethodConfiguration 

pub struct UpdatePaymentMethodConfiguration { /* private fields */ }
Update payment method configuration

Implementations

Source

impl UpdatePaymentMethodConfiguration

pub fn new(configuration: impl Into<PaymentMethodConfigurationId>) -> Self

Construct a new UpdatePaymentMethodConfiguration.

pub fn acss_debit( self, acss_debit: impl Into<UpdatePaymentMethodConfigurationAcssDebit>, ) -> Self

Canadian pre-authorized debit payments, check this page for more details like country availability.

pub fn active(self, active: impl Into<bool>) -> Self

Whether the configuration can be used for new payments.

pub fn affirm( self, affirm: impl Into<UpdatePaymentMethodConfigurationAffirm>, ) -> Self

Affirm gives your customers a way to split purchases over a series of payments. Depending on the purchase, they can pay with four interest-free payments (Split Pay) or pay over a longer term (Installments), which might include interest. Check this page for more details like country availability.

pub fn afterpay_clearpay( self, afterpay_clearpay: impl Into<UpdatePaymentMethodConfigurationAfterpayClearpay>, ) -> Self

Afterpay gives your customers a way to pay for purchases in installments, check this page for more details like country availability. Afterpay is particularly popular among businesses selling fashion, beauty, and sports products.

pub fn alipay( self, alipay: impl Into<UpdatePaymentMethodConfigurationAlipay>, ) -> Self

Alipay is a digital wallet in China that has more than a billion active users worldwide. Alipay users can pay on the web or on a mobile device using login credentials or their Alipay app. Alipay has a low dispute rate and reduces fraud by authenticating payments using the customer’s login credentials. Check this page for more details.

pub fn alma(self, alma: impl Into<UpdatePaymentMethodConfigurationAlma>) -> Self

Alma is a Buy Now, Pay Later payment method that offers customers the ability to pay in 2, 3, or 4 installments.

pub fn amazon_pay( self, amazon_pay: impl Into<UpdatePaymentMethodConfigurationAmazonPay>, ) -> Self

Amazon Pay is a wallet payment method that lets your customers check out the same way as on Amazon.

pub fn apple_pay( self, apple_pay: impl Into<UpdatePaymentMethodConfigurationApplePay>, ) -> Self

Stripe users can accept Apple Pay in iOS applications in iOS 9 and later, and on the web in Safari starting with iOS 10 or macOS Sierra. There are no additional fees to process Apple Pay payments, and the pricing is the same as other card transactions. Check this page for more details.

pub fn apple_pay_later( self, apple_pay_later: impl Into<UpdatePaymentMethodConfigurationApplePayLater>, ) -> Self

Apple Pay Later, a payment method for customers to buy now and pay later, gives your customers a way to split purchases into four installments across six weeks.

pub fn au_becs_debit( self, au_becs_debit: impl Into<UpdatePaymentMethodConfigurationAuBecsDebit>, ) -> Self

Stripe users in Australia can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with an Australian bank account. Check this page for more details.

pub fn bacs_debit( self, bacs_debit: impl Into<UpdatePaymentMethodConfigurationBacsDebit>, ) -> Self

Stripe users in the UK can accept Bacs Direct Debit payments from customers with a UK bank account, check this page for more details.

pub fn bancontact( self, bancontact: impl Into<UpdatePaymentMethodConfigurationBancontact>, ) -> Self

Bancontact is the most popular online payment method in Belgium, with over 15 million cards in circulation. Customers use a Bancontact card or mobile app linked to a Belgian bank account to make online payments that are secure, guaranteed, and confirmed immediately. Check this page for more details.

pub fn billie( self, billie: impl Into<UpdatePaymentMethodConfigurationBillie>, ) -> Self

Billie is a single-use payment method that offers businesses Pay by Invoice where they offer payment terms ranging from 7-120 days. Customers are redirected from your website or app, authorize the payment with Billie, then return to your website or app. You get immediate notification of whether the payment succeeded or failed.

pub fn blik(self, blik: impl Into<UpdatePaymentMethodConfigurationBlik>) -> Self

BLIK is a single use payment method that requires customers to authenticate their payments. When customers want to pay online using BLIK, they request a six-digit code from their banking application and enter it into the payment collection form. Check this page for more details.

pub fn boleto( self, boleto: impl Into<UpdatePaymentMethodConfigurationBoleto>, ) -> Self

Boleto is an official (regulated by the Central Bank of Brazil) payment method in Brazil. Check this page for more details.

pub fn card(self, card: impl Into<UpdatePaymentMethodConfigurationCard>) -> Self

Cards are a popular way for consumers and businesses to pay online or in person. Stripe supports global and local card networks.

pub fn cartes_bancaires( self, cartes_bancaires: impl Into<UpdatePaymentMethodConfigurationCartesBancaires>, ) -> Self

Cartes Bancaires is France’s local card network. More than 95% of these cards are co-branded with either Visa or Mastercard, meaning you can process these cards over either Cartes Bancaires or the Visa or Mastercard networks. Check this page for more details.

pub fn cashapp( self, cashapp: impl Into<UpdatePaymentMethodConfigurationCashapp>, ) -> Self

Cash App is a popular consumer app in the US that allows customers to bank, invest, send, and receive money using their digital wallet. Check this page for more details.

pub fn crypto( self, crypto: impl Into<UpdatePaymentMethodConfigurationCrypto>, ) -> Self

Stablecoin payments enable customers to pay in stablecoins like USDC from 100s of wallets including Phantom and Metamask.

pub fn customer_balance( self, customer_balance: impl Into<UpdatePaymentMethodConfigurationCustomerBalance>, ) -> Self

Uses a customer’s cash balance for the payment. The cash balance can be funded via a bank transfer. Check this page for more details.

pub fn eps(self, eps: impl Into<UpdatePaymentMethodConfigurationEps>) -> Self

EPS is an Austria-based payment method that allows customers to complete transactions online using their bank credentials. EPS is supported by all Austrian banks and is accepted by over 80% of Austrian online retailers. Check this page for more details.

pub fn expand(self, expand: impl Into<Vec<String>>) -> Self

Specifies which fields in the response should be expanded.

pub fn fpx(self, fpx: impl Into<UpdatePaymentMethodConfigurationFpx>) -> Self

Financial Process Exchange (FPX) is a Malaysia-based payment method that allows customers to complete transactions online using their bank credentials. Bank Negara Malaysia (BNM), the Central Bank of Malaysia, and eleven other major Malaysian financial institutions are members of the PayNet Group, which owns and operates FPX. It is one of the most popular online payment methods in Malaysia, with nearly 90 million transactions in 2018 according to BNM. Check this page for more details.

pub fn fr_meal_voucher_conecs( self, fr_meal_voucher_conecs: impl Into<UpdatePaymentMethodConfigurationFrMealVoucherConecs>, ) -> Self

Meal vouchers in France, or “titres-restaurant”, is a local benefits program commonly offered by employers for their employees to purchase prepared food and beverages on working days. Check this page for more details.

pub fn giropay( self, giropay: impl Into<UpdatePaymentMethodConfigurationGiropay>, ) -> Self

giropay is a German payment method based on online banking, introduced in 2006. It allows customers to complete transactions online using their online banking environment, with funds debited from their bank account. Depending on their bank, customers confirm payments on giropay using a second factor of authentication or a PIN. giropay accounts for 10% of online checkouts in Germany. Check this page for more details.

pub fn google_pay( self, google_pay: impl Into<UpdatePaymentMethodConfigurationGooglePay>, ) -> Self

Google Pay allows customers to make payments in your app or website using any credit or debit card saved to their Google Account, including those from Google Play, YouTube, Chrome, or an Android device. Use the Google Pay API to request any credit or debit card stored in your customer’s Google account. Check this page for more details.

pub fn grabpay( self, grabpay: impl Into<UpdatePaymentMethodConfigurationGrabpay>, ) -> Self

GrabPay is a payment method developed by Grab. GrabPay is a digital wallet - customers maintain a balance in their wallets that they pay out with. Check this page for more details.

pub fn ideal( self, ideal: impl Into<UpdatePaymentMethodConfigurationIdeal>, ) -> Self

iDEAL is a Netherlands-based payment method that allows customers to complete transactions online using their bank credentials. All major Dutch banks are members of Currence, the scheme that operates iDEAL, making it the most popular online payment method in the Netherlands with a share of online transactions close to 55%. Check this page for more details.

pub fn jcb(self, jcb: impl Into<UpdatePaymentMethodConfigurationJcb>) -> Self

JCB is a credit card company based in Japan. JCB is currently available in Japan to businesses approved by JCB, and available to all businesses in Australia, Canada, Hong Kong, Japan, New Zealand, Singapore, Switzerland, United Kingdom, United States, and all countries in the European Economic Area except Iceland. Check this page for more details.

pub fn kakao_pay( self, kakao_pay: impl Into<UpdatePaymentMethodConfigurationKakaoPay>, ) -> Self

Kakao Pay is a popular local wallet available in South Korea.

pub fn klarna( self, klarna: impl Into<UpdatePaymentMethodConfigurationKlarna>, ) -> Self

Klarna gives customers a range of payment options during checkout. Available payment options vary depending on the customer’s billing address and the transaction amount. These payment options make it convenient for customers to purchase items in all price ranges. Check this page for more details.

pub fn konbini( self, konbini: impl Into<UpdatePaymentMethodConfigurationKonbini>, ) -> Self

Konbini allows customers in Japan to pay for bills and online purchases at convenience stores with cash. Check this page for more details.

pub fn kr_card( self, kr_card: impl Into<UpdatePaymentMethodConfigurationKrCard>, ) -> Self

Korean cards let users pay using locally issued cards from South Korea.

Link is a payment method network. With Link, users save their payment details once, then reuse that information to pay with one click for any business on the network.

pub fn mb_way( self, mb_way: impl Into<UpdatePaymentMethodConfigurationMbWay>, ) -> Self

MB WAY is the most popular wallet in Portugal. After entering their phone number in your checkout, customers approve the payment directly in their MB WAY app. Check this page for more details.

pub fn mobilepay( self, mobilepay: impl Into<UpdatePaymentMethodConfigurationMobilepay>, ) -> Self

MobilePay is a single-use card wallet payment method used in Denmark and Finland. It allows customers to authenticate and approve payments using the MobilePay app. Check this page for more details.

pub fn multibanco( self, multibanco: impl Into<UpdatePaymentMethodConfigurationMultibanco>, ) -> Self

Stripe users in Europe and the United States can accept Multibanco payments from customers in Portugal using Sources—a single integration path for creating payments using any supported method.

pub fn name(self, name: impl Into<String>) -> Self

Configuration name.

pub fn naver_pay( self, naver_pay: impl Into<UpdatePaymentMethodConfigurationNaverPay>, ) -> Self

Naver Pay is a popular local wallet available in South Korea.

pub fn nz_bank_account( self, nz_bank_account: impl Into<UpdatePaymentMethodConfigurationNzBankAccount>, ) -> Self

Stripe users in New Zealand can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with a New Zeland bank account. Check this page for more details.

pub fn oxxo(self, oxxo: impl Into<UpdatePaymentMethodConfigurationOxxo>) -> Self

OXXO is a Mexican chain of convenience stores with thousands of locations across Latin America and represents nearly 20% of online transactions in Mexico. OXXO allows customers to pay bills and online purchases in-store with cash. Check this page for more details.

pub fn p24(self, p24: impl Into<UpdatePaymentMethodConfigurationP24>) -> Self

Przelewy24 is a Poland-based payment method aggregator that allows customers to complete transactions online using bank transfers and other methods. Bank transfers account for 30% of online payments in Poland and Przelewy24 provides a way for customers to pay with over 165 banks. Check this page for more details.

pub fn pay_by_bank( self, pay_by_bank: impl Into<UpdatePaymentMethodConfigurationPayByBank>, ) -> Self

Pay by bank is a redirect payment method backed by bank transfers. A customer is redirected to their bank to authorize a bank transfer for a given amount. This removes a lot of the error risks inherent in waiting for the customer to initiate a transfer themselves, and is less expensive than card payments.

pub fn payco( self, payco: impl Into<UpdatePaymentMethodConfigurationPayco>, ) -> Self

PAYCO is a [single-use](https://docs.stripe.com/payments/payment-methods#usage local wallet available in South Korea.

pub fn paynow( self, paynow: impl Into<UpdatePaymentMethodConfigurationPaynow>, ) -> Self

PayNow is a Singapore-based payment method that allows customers to make a payment using their preferred app from participating banks and participating non-bank financial institutions. Check this page for more details.

pub fn paypal( self, paypal: impl Into<UpdatePaymentMethodConfigurationPaypal>, ) -> Self

PayPal, a digital wallet popular with customers in Europe, allows your customers worldwide to pay using their PayPal account. Check this page for more details.

pub fn payto( self, payto: impl Into<UpdatePaymentMethodConfigurationPayto>, ) -> Self

PayTo is a real-time payment method that enables customers in Australia to pay by providing their bank account details. Customers must accept a mandate authorizing you to debit their account. Check this page for more details.

pub fn pix(self, pix: impl Into<UpdatePaymentMethodConfigurationPix>) -> Self

Pix is a payment method popular in Brazil. When paying with Pix, customers authenticate and approve payments by scanning a QR code in their preferred banking app. Check this page for more details.

pub fn promptpay( self, promptpay: impl Into<UpdatePaymentMethodConfigurationPromptpay>, ) -> Self

PromptPay is a Thailand-based payment method that allows customers to make a payment using their preferred app from participating banks. Check this page for more details.

pub fn revolut_pay( self, revolut_pay: impl Into<UpdatePaymentMethodConfigurationRevolutPay>, ) -> Self

Revolut Pay, developed by Revolut, a global finance app, is a digital wallet payment method. Revolut Pay uses the customer’s stored balance or cards to fund the payment, and offers the option for non-Revolut customers to save their details after their first purchase.

pub fn samsung_pay( self, samsung_pay: impl Into<UpdatePaymentMethodConfigurationSamsungPay>, ) -> Self

Samsung Pay is a [single-use](https://docs.stripe.com/payments/payment-methods#usage local wallet available in South Korea.

pub fn satispay( self, satispay: impl Into<UpdatePaymentMethodConfigurationSatispay>, ) -> Self

Satispay is a single-use payment method where customers are required to authenticate their payment. Customers pay by being redirected from your website or app, authorizing the payment with Satispay, then returning to your website or app. You get immediate notification of whether the payment succeeded or failed.

pub fn sepa_debit( self, sepa_debit: impl Into<UpdatePaymentMethodConfigurationSepaDebit>, ) -> Self

The Single Euro Payments Area (SEPA) is an initiative of the European Union to simplify payments within and across member countries. SEPA established and enforced banking standards to allow for the direct debiting of every EUR-denominated bank account within the SEPA region, check this page for more details.

pub fn sofort( self, sofort: impl Into<UpdatePaymentMethodConfigurationSofort>, ) -> Self

Stripe users in Europe and the United States can use the Payment Intents API—a single integration path for creating payments using any supported method—to accept Sofort payments from customers. Check this page for more details.

pub fn swish( self, swish: impl Into<UpdatePaymentMethodConfigurationSwish>, ) -> Self

Swish is a real-time payment method popular in Sweden. It allows customers to authenticate and approve payments using the Swish mobile app and the Swedish BankID mobile app. Check this page for more details.

pub fn twint( self, twint: impl Into<UpdatePaymentMethodConfigurationTwint>, ) -> Self

Twint is a payment method popular in Switzerland. It allows customers to pay using their mobile phone. Check this page for more details.

pub fn upi(self, upi: impl Into<UpdatePaymentMethodConfigurationUpi>) -> Self

Unified Payment Interface (UPI) is India’s leading payment method with exponential growth since it launched in 2016.

pub fn us_bank_account( self, us_bank_account: impl Into<UpdatePaymentMethodConfigurationUsBankAccount>, ) -> Self

Stripe users in the United States can accept ACH direct debit payments from customers with a US bank account using the Automated Clearing House (ACH) payments system operated by Nacha. Check this page for more details.

pub fn wechat_pay( self, wechat_pay: impl Into<UpdatePaymentMethodConfigurationWechatPay>, ) -> Self

WeChat, owned by Tencent, is China’s leading mobile app with over 1 billion monthly active users. Chinese consumers can use WeChat Pay to pay for goods and services inside of businesses’ apps and websites. WeChat Pay users buy most frequently in gaming, e-commerce, travel, online education, and food/nutrition. Check this page for more details.

pub fn zip(self, zip: impl Into<UpdatePaymentMethodConfigurationZip>) -> Self

Zip gives your customers a way to split purchases over a series of payments. Check this page for more details like country availability.

Source

impl UpdatePaymentMethodConfiguration

pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response.

pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response, blocking until completion.