pub struct UpdatePaymentMethodConfigurationAcssDebit {
pub display_preference: Option<UpdatePaymentMethodConfigurationAcssDebitDisplayPreference>,
}Expand description
Canadian pre-authorized debit payments, check this page for more details like country availability.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationAcssDebitDisplayPreference>Whether or not the payment method should be displayed.
Implementations