pub struct UpdatePaymentMethodConfigurationAlipayDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationAlipayDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationAlipayDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations