pub struct UpdatePaymentMethodConfigurationAlmaDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationAlmaDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationAlmaDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations