UpdatePaymentMethodConfigurationApplePay

Struct UpdatePaymentMethodConfigurationApplePay 

pub struct UpdatePaymentMethodConfigurationApplePay {
    pub display_preference: Option<UpdatePaymentMethodConfigurationApplePayDisplayPreference>,
}
Stripe users can accept Apple Pay in iOS applications in iOS 9 and later, and on the web in Safari starting with iOS 10 or macOS Sierra. There are no additional fees to process Apple Pay payments, and the pricing is the same as other card transactions. Check this page for more details.

Fields

display_preference: Option<UpdatePaymentMethodConfigurationApplePayDisplayPreference>

Whether or not the payment method should be displayed.

Implementations