pub struct UpdatePaymentMethodConfigurationBacsDebitDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationBacsDebitDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationBacsDebitDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations