pub struct UpdatePaymentMethodConfigurationBancontactDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationBancontactDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationBancontactDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations