pub struct UpdatePaymentMethodConfigurationBillieDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationBillieDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationBillieDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations