pub struct UpdatePaymentMethodConfigurationBlik {
pub display_preference: Option<UpdatePaymentMethodConfigurationBlikDisplayPreference>,
}Expand description
BLIK is a single use payment method that requires customers to authenticate their payments. When customers want to pay online using BLIK, they request a six-digit code from their banking application and enter it into the payment collection form. Check this page for more details.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationBlikDisplayPreference>Whether or not the payment method should be displayed.
Implementations