pub struct UpdatePaymentMethodConfigurationBlikDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationBlikDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationBlikDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations