pub struct UpdatePaymentMethodConfigurationCard {
pub display_preference: Option<UpdatePaymentMethodConfigurationCardDisplayPreference>,
}Expand description
Cards are a popular way for consumers and businesses to pay online or in person. Stripe supports global and local card networks.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationCardDisplayPreference>Whether or not the payment method should be displayed.
Implementations