pub struct UpdatePaymentMethodConfigurationCardDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationCardDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationCardDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations