pub struct UpdatePaymentMethodConfigurationCrypto {
pub display_preference: Option<UpdatePaymentMethodConfigurationCryptoDisplayPreference>,
}Expand description
Stablecoin payments enable customers to pay in stablecoins like USDC from 100s of wallets including Phantom and Metamask.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationCryptoDisplayPreference>Whether or not the payment method should be displayed.
Implementations