pub struct UpdatePaymentMethodConfigurationCryptoDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationCryptoDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationCryptoDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations