pub struct UpdatePaymentMethodConfigurationCustomerBalance {
pub display_preference: Option<UpdatePaymentMethodConfigurationCustomerBalanceDisplayPreference>,
}Expand description
Uses a customer’s cash balance for the payment. The cash balance can be funded via a bank transfer. Check this page for more details.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationCustomerBalanceDisplayPreference>Whether or not the payment method should be displayed.
Implementations