pub struct UpdatePaymentMethodConfigurationCustomerBalanceDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationCustomerBalanceDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationCustomerBalanceDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations