pub struct UpdatePaymentMethodConfigurationGiropay {
pub display_preference: Option<UpdatePaymentMethodConfigurationGiropayDisplayPreference>,
}Expand description
giropay is a German payment method based on online banking, introduced in 2006. It allows customers to complete transactions online using their online banking environment, with funds debited from their bank account. Depending on their bank, customers confirm payments on giropay using a second factor of authentication or a PIN. giropay accounts for 10% of online checkouts in Germany. Check this page for more details.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationGiropayDisplayPreference>Whether or not the payment method should be displayed.
Implementations