pub struct UpdatePaymentMethodConfigurationGiropayDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationGiropayDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationGiropayDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations