pub struct UpdatePaymentMethodConfigurationGooglePay {
pub display_preference: Option<UpdatePaymentMethodConfigurationGooglePayDisplayPreference>,
}Expand description
Google Pay allows customers to make payments in your app or website using any credit or debit card saved to their Google Account, including those from Google Play, YouTube, Chrome, or an Android device. Use the Google Pay API to request any credit or debit card stored in your customer’s Google account. Check this page for more details.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationGooglePayDisplayPreference>Whether or not the payment method should be displayed.
Implementations