pub struct UpdatePaymentMethodConfigurationGooglePayDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationGooglePayDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationGooglePayDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations