pub struct UpdatePaymentMethodConfigurationGrabpayDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationGrabpayDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationGrabpayDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations