pub struct UpdatePaymentMethodConfigurationJcb {
pub display_preference: Option<UpdatePaymentMethodConfigurationJcbDisplayPreference>,
}Expand description
JCB is a credit card company based in Japan. JCB is currently available in Japan to businesses approved by JCB, and available to all businesses in Australia, Canada, Hong Kong, Japan, New Zealand, Singapore, Switzerland, United Kingdom, United States, and all countries in the European Economic Area except Iceland. Check this page for more details.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationJcbDisplayPreference>Whether or not the payment method should be displayed.
Implementations