pub struct UpdatePaymentMethodConfigurationKakaoPayDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationKakaoPayDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationKakaoPayDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations