pub struct UpdatePaymentMethodConfigurationKlarnaDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationKlarnaDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationKlarnaDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations