pub struct UpdatePaymentMethodConfigurationKonbiniDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationKonbiniDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationKonbiniDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations