pub struct UpdatePaymentMethodConfigurationKrCard {
pub display_preference: Option<UpdatePaymentMethodConfigurationKrCardDisplayPreference>,
}Expand description
Korean cards let users pay using locally issued cards from South Korea.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationKrCardDisplayPreference>Whether or not the payment method should be displayed.
Implementations