pub struct UpdatePaymentMethodConfigurationLink {
pub display_preference: Option<UpdatePaymentMethodConfigurationLinkDisplayPreference>,
}Expand description
Link is a payment method network. With Link, users save their payment details once, then reuse that information to pay with one click for any business on the network.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationLinkDisplayPreference>Whether or not the payment method should be displayed.
Implementations