pub struct UpdatePaymentMethodConfigurationMbWay {
pub display_preference: Option<UpdatePaymentMethodConfigurationMbWayDisplayPreference>,
}Expand description
MB WAY is the most popular wallet in Portugal. After entering their phone number in your checkout, customers approve the payment directly in their MB WAY app. Check this page for more details.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationMbWayDisplayPreference>Whether or not the payment method should be displayed.
Implementations