pub struct UpdatePaymentMethodConfigurationMobilepay {
pub display_preference: Option<UpdatePaymentMethodConfigurationMobilepayDisplayPreference>,
}Expand description
MobilePay is a single-use card wallet payment method used in Denmark and Finland. It allows customers to authenticate and approve payments using the MobilePay app. Check this page for more details.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationMobilepayDisplayPreference>Whether or not the payment method should be displayed.
Implementations