pub struct UpdatePaymentMethodConfigurationMobilepayDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationMobilepayDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationMobilepayDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations