pub struct UpdatePaymentMethodConfigurationMultibancoDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationMultibancoDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationMultibancoDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations