pub struct UpdatePaymentMethodConfigurationNzBankAccountDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationNzBankAccountDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationNzBankAccountDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations