pub struct UpdatePaymentMethodConfigurationP24DisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationP24DisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationP24DisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations