pub struct UpdatePaymentMethodConfigurationPayByBank {
pub display_preference: Option<UpdatePaymentMethodConfigurationPayByBankDisplayPreference>,
}Expand description
Pay by bank is a redirect payment method backed by bank transfers. A customer is redirected to their bank to authorize a bank transfer for a given amount. This removes a lot of the error risks inherent in waiting for the customer to initiate a transfer themselves, and is less expensive than card payments.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationPayByBankDisplayPreference>Whether or not the payment method should be displayed.
Implementations