pub struct UpdatePaymentMethodConfigurationPaycoDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationPaycoDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationPaycoDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations