pub struct UpdatePaymentMethodConfigurationPaynow {
pub display_preference: Option<UpdatePaymentMethodConfigurationPaynowDisplayPreference>,
}Expand description
PayNow is a Singapore-based payment method that allows customers to make a payment using their preferred app from participating banks and participating non-bank financial institutions. Check this page for more details.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationPaynowDisplayPreference>Whether or not the payment method should be displayed.
Implementations