pub struct UpdatePaymentMethodConfigurationPaypal {
pub display_preference: Option<UpdatePaymentMethodConfigurationPaypalDisplayPreference>,
}Expand description
PayPal, a digital wallet popular with customers in Europe, allows your customers worldwide to pay using their PayPal account. Check this page for more details.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationPaypalDisplayPreference>Whether or not the payment method should be displayed.
Implementations