pub struct UpdatePaymentMethodConfigurationRevolutPayDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationRevolutPayDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationRevolutPayDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations