pub struct UpdatePaymentMethodConfigurationSatispayDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationSatispayDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationSatispayDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations