pub struct UpdatePaymentMethodConfigurationSepaDebitDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationSepaDebitDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationSepaDebitDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations