pub struct UpdatePaymentMethodConfigurationSofort {
pub display_preference: Option<UpdatePaymentMethodConfigurationSofortDisplayPreference>,
}Expand description
Stripe users in Europe and the United States can use the Payment Intents API—a single integration path for creating payments using any supported method—to accept Sofort payments from customers. Check this page for more details.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationSofortDisplayPreference>Whether or not the payment method should be displayed.
Implementations