pub struct UpdatePaymentMethodConfigurationSofortDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationSofortDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationSofortDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations