pub struct UpdatePaymentMethodConfigurationTwintDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationTwintDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationTwintDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations