pub struct UpdatePaymentMethodConfigurationUsBankAccount {
pub display_preference: Option<UpdatePaymentMethodConfigurationUsBankAccountDisplayPreference>,
}Expand description
Stripe users in the United States can accept ACH direct debit payments from customers with a US bank account using the Automated Clearing House (ACH) payments system operated by Nacha. Check this page for more details.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationUsBankAccountDisplayPreference>Whether or not the payment method should be displayed.
Implementations