pub struct UpdatePaymentMethodConfigurationUsBankAccountDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationUsBankAccountDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationUsBankAccountDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations