pub struct UpdatePaymentMethodConfigurationWechatPay {
pub display_preference: Option<UpdatePaymentMethodConfigurationWechatPayDisplayPreference>,
}Expand description
WeChat, owned by Tencent, is China’s leading mobile app with over 1 billion monthly active users. Chinese consumers can use WeChat Pay to pay for goods and services inside of businesses’ apps and websites. WeChat Pay users buy most frequently in gaming, e-commerce, travel, online education, and food/nutrition. Check this page for more details.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationWechatPayDisplayPreference>Whether or not the payment method should be displayed.
Implementations