pub struct UpdatePaymentMethodConfigurationWechatPayDisplayPreference {
pub preference: Option<UpdatePaymentMethodConfigurationWechatPayDisplayPreferencePreference>,
}Expand description
Whether or not the payment method should be displayed.
Fields
preference: Option<UpdatePaymentMethodConfigurationWechatPayDisplayPreferencePreference>The account’s preference for whether or not to display this payment method.
Implementations