pub struct UpdatePaymentMethodConfigurationZip {
pub display_preference: Option<UpdatePaymentMethodConfigurationZipDisplayPreference>,
}Expand description
Zip gives your customers a way to split purchases over a series of payments. Check this page for more details like country availability.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationZipDisplayPreference>Whether or not the payment method should be displayed.
Implementations