ValidatePaymentMethodDomain

Struct ValidatePaymentMethodDomain 

pub struct ValidatePaymentMethodDomain { /* private fields */ }
Some payment methods might require additional steps to register a domain. If the requirements weren’t satisfied when the domain was created, the payment method will be inactive on the domain. The payment method doesn’t appear in Elements or Embedded Checkout for this domain until it is active.

To activate a payment method on an existing payment method domain, complete the required registration steps specific to the payment method, and then validate the payment method domain with this endpoint.

Related guides: Payment method domains.

Implementations

Source

impl ValidatePaymentMethodDomain

pub fn new(payment_method_domain: impl Into<PaymentMethodDomainId>) -> Self

Construct a new ValidatePaymentMethodDomain.

pub fn expand(self, expand: impl Into<Vec<String>>) -> Self

Specifies which fields in the response should be expanded.

Source

impl ValidatePaymentMethodDomain

pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response.

pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response, blocking until completion.