#[non_exhaustive]pub enum CreateSourceMandateNotificationMethod {
DeprecatedNone,
Email,
Manual,
None,
StripeEmail,
Unknown(String),
}Expand description
The method Stripe should use to notify the customer of upcoming debit instructions and/or mandate confirmation as required by the underlying debit network.
Either email (an email is sent directly to the customer), manual (a source.mandate_notification event is sent to your webhooks endpoint and you should handle the notification) or none (the underlying debit network does not require any notification).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DeprecatedNone
Manual
None
StripeEmail
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations