#[non_exhaustive]pub enum CreateSourceReceiverRefundAttributesMethod {
Email,
Manual,
None,
Unknown(String),
}Expand description
The method Stripe should use to request information needed to process a refund or mispayment.
Either email (an email is sent directly to the customer) or manual (a source.refund_attributes_required event is sent to your webhooks endpoint).
Refer to each payment method’s documentation to learn which refund attributes may be required.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Manual
None
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations