CreateSourceMandate

Struct CreateSourceMandate 

pub struct CreateSourceMandate {
    pub acceptance: Option<CreateSourceMandateAcceptance>,
    pub amount: Option<i64>,
    pub currency: Option<Currency>,
    pub interval: Option<CreateSourceMandateInterval>,
    pub notification_method: Option<CreateSourceMandateNotificationMethod>,
}
Information about a mandate possibility attached to a source object (generally for bank debits) as well as its acceptance status.

Fields

acceptance: Option<CreateSourceMandateAcceptance>

The parameters required to notify Stripe of a mandate acceptance or refusal by the customer.

amount: Option<i64>

The amount specified by the mandate. (Leave null for a mandate covering all amounts)

currency: Option<Currency>

The currency specified by the mandate. (Must match currency of the source)

interval: Option<CreateSourceMandateInterval>

The interval of debits permitted by the mandate. Either one_time (just permitting a single debit), scheduled (with debits on an agreed schedule or for clearly-defined events), or variable(for debits with any frequency).

notification_method: Option<CreateSourceMandateNotificationMethod>

The method Stripe should use to notify the customer of upcoming debit instructions and/or mandate confirmation as required by the underlying debit network. Either email (an email is sent directly to the customer), manual (a source.mandate_notification event is sent to your webhooks endpoint and you should handle the notification) or none (the underlying debit network does not require any notification).

Implementations