pub struct CreateSourceMandateAcceptance {
pub date: Option<Timestamp>,
pub ip: Option<String>,
pub offline: Option<MandateOfflineAcceptanceParams>,
pub online: Option<MandateOnlineAcceptanceParams>,
pub status: CreateSourceMandateAcceptanceStatus,
pub type_: Option<CreateSourceMandateAcceptanceType>,
pub user_agent: Option<String>,
}Expand description
The parameters required to notify Stripe of a mandate acceptance or refusal by the customer.
Fields
date: Option<Timestamp>The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.
ip: Option<String>The IP address from which the mandate was accepted or refused by the customer.
offline: Option<MandateOfflineAcceptanceParams>The parameters required to store a mandate accepted offline.
Should only be set if mandate[type] is offline.
online: Option<MandateOnlineAcceptanceParams>The parameters required to store a mandate accepted online.
Should only be set if mandate[type] is online.
status: CreateSourceMandateAcceptanceStatusThe status of the mandate acceptance.
Either accepted (the mandate was accepted) or refused (the mandate was refused).
type_: Option<CreateSourceMandateAcceptanceType>The type of acceptance information included with the mandate. Either online or offline
user_agent: Option<String>The user agent of the browser from which the mandate was accepted or refused by the customer.
Implementations
Sourceimpl CreateSourceMandateAcceptance
impl CreateSourceMandateAcceptance
pub fn new(status: impl Into<CreateSourceMandateAcceptanceStatus>) -> Self