pub struct CreateSourceRedirect {
pub return_url: String,
}Expand description
Parameters required for the redirect flow.
Required if the source is authenticated by a redirect (flow is redirect).
Fields
return_url: StringThe URL you provide to redirect the customer back to you after they authenticated their payment. It can use your application URI scheme in the context of a mobile application.
Implementations