CreateSourceSourceOrder

Struct CreateSourceSourceOrder 

pub struct CreateSourceSourceOrder {
    pub items: Option<Vec<CreateSourceSourceOrderItems>>,
    pub shipping: Option<OrderShipping>,
}
Information about the items and shipping associated with the source. Required for transactional credit (for example Klarna) sources before you can charge it.

Fields

items: Option<Vec<CreateSourceSourceOrderItems>>

List of items constituting the order.

shipping: Option<OrderShipping>

Shipping address for the order. Required if any of the SKUs are for products that have shippable set to true.

Implementations