pub struct OrderShipping {
pub address: Address,
pub carrier: Option<String>,
pub name: Option<String>,
pub phone: Option<String>,
pub tracking_number: Option<String>,
}Fields
address: AddressShipping address.
carrier: Option<String>The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
name: Option<String>Recipient name.
phone: Option<String>Recipient phone (including extension).
tracking_number: Option<String>The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
Implementations