Struct PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceInstallmentPlan
pub struct PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceInstallmentPlan {
pub count: Option<u64>,
pub interval: Option<PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceInstallmentPlanInterval>,
pub type_: PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceInstallmentPlanType,
}Fields
count: Option<u64>For fixed_count installment plans, this is the number of installment payments your customer will make to their credit card.
interval: Option<PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceInstallmentPlanInterval>For fixed_count installment plans, this is the interval between installment payments your customer will make to their credit card.
One of month.
type_: PaymentsPrimitivesPaymentRecordsResourcePaymentMethodCardDetailsResourceInstallmentPlanTypeType of installment plan, one of fixed_count, revolving, or bonus.