#[non_exhaustive]pub enum CreatePaymentLinkConsentCollectionPaymentMethodReuseAgreementPosition {
Auto,
Hidden,
Unknown(String),
}Expand description
Determines the position and visibility of the payment method reuse agreement in the UI.
When set to auto, Stripe’s.
defaults will be used.
When set to hidden, the payment method reuse agreement text will always be hidden in the UI.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auto
Hidden
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations