pub struct CreatePaymentMethodConfigurationBillie {
pub display_preference: Option<CreatePaymentMethodConfigurationBillieDisplayPreference>,
}Expand description
Billie is a single-use payment method that offers businesses Pay by Invoice where they offer payment terms ranging from 7-120 days. Customers are redirected from your website or app, authorize the payment with Billie, then return to your website or app. You get immediate notification of whether the payment succeeded or failed.
Fields
display_preference: Option<CreatePaymentMethodConfigurationBillieDisplayPreference>Whether or not the payment method should be displayed.
Implementations