pub struct CreatePaymentMethodConfigurationFpx {
pub display_preference: Option<CreatePaymentMethodConfigurationFpxDisplayPreference>,
}Expand description
Financial Process Exchange (FPX) is a Malaysia-based payment method that allows customers to complete transactions online using their bank credentials. Bank Negara Malaysia (BNM), the Central Bank of Malaysia, and eleven other major Malaysian financial institutions are members of the PayNet Group, which owns and operates FPX. It is one of the most popular online payment methods in Malaysia, with nearly 90 million transactions in 2018 according to BNM. Check this page for more details.
Fields
display_preference: Option<CreatePaymentMethodConfigurationFpxDisplayPreference>Whether or not the payment method should be displayed.
Implementations