pub struct CreatePaymentMethodConfigurationSwish {
pub display_preference: Option<CreatePaymentMethodConfigurationSwishDisplayPreference>,
}Expand description
Swish is a real-time payment method popular in Sweden. It allows customers to authenticate and approve payments using the Swish mobile app and the Swedish BankID mobile app. Check this page for more details.
Fields
display_preference: Option<CreatePaymentMethodConfigurationSwishDisplayPreference>Whether or not the payment method should be displayed.
Implementations