pub struct UpdatePaymentMethodConfigurationMultibanco {
pub display_preference: Option<UpdatePaymentMethodConfigurationMultibancoDisplayPreference>,
}Expand description
Stripe users in Europe and the United States can accept Multibanco payments from customers in Portugal using Sources—a single integration path for creating payments using any supported method.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationMultibancoDisplayPreference>Whether or not the payment method should be displayed.
Implementations