pub struct UpdatePaymentMethodConfigurationSepaDebit {
pub display_preference: Option<UpdatePaymentMethodConfigurationSepaDebitDisplayPreference>,
}Expand description
The Single Euro Payments Area (SEPA) is an initiative of the European Union to simplify payments within and across member countries. SEPA established and enforced banking standards to allow for the direct debiting of every EUR-denominated bank account within the SEPA region, check this page for more details.
Fields
display_preference: Option<UpdatePaymentMethodConfigurationSepaDebitDisplayPreference>Whether or not the payment method should be displayed.
Implementations